@@ -13,9 +13,9 @@
 #include "shared/source/command_stream/thread_arbitration_policy.h"
 #include "shared/source/helpers/blit_properties.h"
 #include "shared/source/helpers/cache_policy.h"
-#include "shared/source/helpers/common_types.h"
 #include "shared/source/helpers/definitions/command_encoder_args.h"
 #include "shared/source/helpers/heap_base_address_model.h"
+#include "shared/source/helpers/private_allocs_to_reuse_container.h"
 #include "shared/source/memory_manager/graphics_allocation.h"
 #include "shared/source/memory_manager/prefetch_manager.h"
 #include "shared/source/unified_memory/unified_memory.h"
@@ -24,6 +24,7 @@
 #include "level_zero/core/source/cmdlist/command_to_patch.h"
 #include "level_zero/core/source/helpers/api_handle_helper.h"
 #include "level_zero/experimental/source/graph/graph.h"
+#include "level_zero/include/level_zero/driver_experimental/zex_cmdlist.h"
 #include "level_zero/include/level_zero/ze_intel_gpu.h"
 #include <level_zero/ze_api.h>
 #include <level_zero/zet_api.h>
@@ -44,6 +45,7 @@ class TagNodeBase;
 struct EncodeDispatchKernelArgs;
 class CommandStreamReceiver;
 class GraphicsAllocation;
+struct HostFunction;
 } // namespace NEO
 
 namespace L0 {
@@ -260,6 +262,7 @@ struct CommandList : _ze_command_list_handle_t {
     }
 
     static ze_result_t setKernelState(Kernel *kernel, const ze_group_size_t groupSizes, void **arguments);
+    static uint32_t getLimitIsaPrefetchSize();
     static ze_result_t cloneAppendKernelExtensions(const ze_base_desc_t *desc, void *&outPnext);
     static void freeClonedAppendKernelExtensions(void *pNext);
     static ze_result_t cloneAppendMemoryCopyExtensions(const ze_base_desc_t *desc, void *&outPnext);
@@ -271,7 +274,7 @@ struct CommandList : _ze_command_list_handle_t {
         return commandListPerThreadScratchSize[slotId];
     }
 
-    void setAdditionalDispatchKernelArgsFromLaunchParams(NEO::EncodeDispatchKernelArgs &dispatchKernelArgs, const CmdListKernelLaunchParams &launchParams) const;
+    MOCKABLE_VIRTUAL void setAdditionalDispatchKernelArgsFromLaunchParams(NEO::EncodeDispatchKernelArgs &dispatchKernelArgs, const CmdListKernelLaunchParams &launchParams) const;
     void setAdditionalDispatchKernelArgsFromKernel(NEO::EncodeDispatchKernelArgs &dispatchKernelArgs, const Kernel *kernel) const;
 
     ze_result_t validateLaunchParams(const Kernel &kernel, const CmdListKernelLaunchParams &launchParams) const;
@@ -549,11 +552,23 @@ struct CommandList : _ze_command_list_handle_t {
         return this->isSyncModeQueue;
     }
 
+    void addCleanupCallback(zex_command_list_cleanup_callback_fn_t callback, void *userData) {
+        this->cleanupCallbacks.emplace_back(callback, userData);
+    }
+
+    void executeCleanupCallbacks();
+    bool verifyMemory(const void *allocationPtr,
+                      const void *expectedData,
+                      size_t sizeOfComparison,
+                      uint32_t comparisonMode) const;
+
   protected:
+    using CleanupCallbackT = std::pair<zex_command_list_cleanup_callback_fn_t, void *>;
+
     virtual void dispatchHostFunction(void *pHostFunction,
                                       void *pUserData) = 0;
 
-    virtual void addHostFunctionToPatchCommands(uint64_t userHostFunctionAddress, uint64_t userDataAddress) = 0;
+    virtual void addHostFunctionToPatchCommands(const NEO::HostFunction &hostFunction) = 0;
 
     NEO::GraphicsAllocation *getAllocationFromHostPtrMap(const void *buffer, uint64_t bufferSize, bool copyOffload);
     NEO::GraphicsAllocation *getHostPtrAlloc(const void *buffer, uint64_t bufferSize, bool hostCopyAllowed, bool copyOffload);
@@ -575,6 +590,7 @@ struct CommandList : _ze_command_list_handle_t {
     std::vector<NEO::GraphicsAllocation *> patternAllocations;
     std::vector<NEO::TagNodeBase *> patternTags;
     std::vector<std::weak_ptr<Kernel>> printfKernelContainer;
+    std::vector<CleanupCallbackT> cleanupCallbacks;
 
     NEO::CommandContainer commandContainer;
 
