@@ -28,6 +28,9 @@ enum class Builtin : uint32_t;
 
 struct Event;
 struct EventPool;
+struct CmdListHostFunctionParameters;
+template <typename GfxFamily>
+class SWTagScope;
 
 #pragma pack(1)
 struct EventData {
@@ -156,6 +159,10 @@ struct CommandListCoreFamily : public CommandListImp {
     ze_result_t appendMemoryCopy(void *dstptr, const void *srcptr, size_t size,
                                  ze_event_handle_t hSignalEvent, uint32_t numWaitEvents,
                                  ze_event_handle_t *phWaitEvents, CmdListMemoryCopyParams &memoryCopyParams) override;
+    ze_result_t appendMemoryCopyWithParameters(void *dstptr, const void *srcptr, size_t size,
+                                               const void *pNext,
+                                               ze_event_handle_t hSignalEvent, uint32_t numWaitEvents,
+                                               ze_event_handle_t *phWaitEvents) override;
     ze_result_t appendPageFaultCopy(NEO::GraphicsAllocation *dstAllocation,
                                     NEO::GraphicsAllocation *srcAllocation,
                                     size_t size,
@@ -177,6 +184,11 @@ struct CommandListCoreFamily : public CommandListImp {
                                  ze_event_handle_t hSignalEvent,
                                  uint32_t numWaitEvents,
                                  ze_event_handle_t *phWaitEvents, CmdListMemoryCopyParams &memoryCopyParams) override;
+    ze_result_t appendMemoryFillWithParameters(void *ptr, const void *pattern,
+                                               size_t patternSize, size_t size,
+                                               const void *pNext,
+                                               ze_event_handle_t hSignalEvent,
+                                               uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents) override;
 
     ze_result_t appendMIBBStart(uint64_t address, size_t predication, bool secondLevel) override;
     ze_result_t appendMIBBEnd() override;
@@ -207,7 +219,7 @@ struct CommandListCoreFamily : public CommandListImp {
     void appendWaitOnInOrderDependency(std::shared_ptr<NEO::InOrderExecInfo> &inOrderExecInfo, CommandToPatchContainer *outListCommands,
                                        uint64_t waitValue, uint32_t offset, bool relaxedOrderingAllowed, bool implicitDependency,
                                        bool skipAddingWaitEventsToResidency, bool noopDispatch, bool dualStreamCopyOffloadOperation);
-    MOCKABLE_VIRTUAL void appendSignalInOrderDependencyCounter(Event *signalEvent, bool copyOffloadOperation, bool stall, bool textureFlushRequired);
+    MOCKABLE_VIRTUAL void appendSignalInOrderDependencyCounter(Event *signalEvent, bool copyOffloadOperation, bool stall, bool textureFlushRequired, bool skipAggregatedEventSignaling);
     void handleInOrderDependencyCounter(Event *signalEvent, bool nonWalkerInOrderCmdsChaining, bool copyOffloadOperation);
     void handleInOrderCounterOverflow(bool copyOffloadOperation);
 
@@ -226,9 +238,16 @@ struct CommandListCoreFamily : public CommandListImp {
     MOCKABLE_VIRTUAL void appendSynchronizedDispatchCleanupSection();
     ze_result_t appendCommandLists(uint32_t numCommandLists, ze_command_list_handle_t *phCommandLists,
                                    ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents) override;
-
+    ze_result_t appendHostFunction(void *pHostFunction,
+                                   void *pUserData,
+                                   void *pNext,
+                                   ze_event_handle_t hSignalEvent,
+                                   uint32_t numWaitEvents,
+                                   ze_event_handle_t *phWaitEvents,
+                                   CmdListHostFunctionParameters &parameters) override;
     ze_result_t reserveSpace(size_t size, void **ptr) override;
     ze_result_t reset() override;
+
     size_t getReserveSshSize();
     void patchInOrderCmds() override;
     MOCKABLE_VIRTUAL bool handleCounterBasedEventOperations(Event *signalEvent, bool skipAddingEventToResidency);
@@ -236,10 +255,16 @@ struct CommandListCoreFamily : public CommandListImp {
     bool kernelMemoryPrefetchEnabled() const override;
     void assignInOrderExecInfoToEvent(Event *event);
     bool hasInOrderDependencies() const;
+    MOCKABLE_VIRTUAL void appendSignalEventPostWalker(Event *event, void **syncCmdBuffer, CommandToPatchContainer *outTimeStampSyncCmds, bool skipBarrierForEndProfiling, bool skipAddingEventToResidency, bool copyOperation);
+    bool isUsingAdditionalBlitProperties() const { return useAdditionalBlitProperties; }
 
   protected:
-    MOCKABLE_VIRTUAL ze_result_t appendMemoryCopyKernelWithGA(void *dstPtr, NEO::GraphicsAllocation *dstPtrAlloc,
-                                                              uint64_t dstOffset, void *srcPtr,
+    void dispatchHostFunction(void *pHostFunction,
+                              void *pUserData) override;
+    void addHostFunctionToPatchCommands(const NEO::HostFunction &hostFunction) override;
+
+    MOCKABLE_VIRTUAL ze_result_t appendMemoryCopyKernelWithGA(uintptr_t dstPtr, NEO::GraphicsAllocation *dstPtrAlloc,
+                                                              uint64_t dstOffset, uintptr_t srcPtr,
                                                               NEO::GraphicsAllocation *srcPtrAlloc,
                                                               uint64_t srcOffset, uint64_t size,
                                                               uint64_t elementSize, Builtin builtin,
@@ -253,7 +278,8 @@ struct CommandListCoreFamily : public CommandListImp {
                                                       NEO::GraphicsAllocation *srcPtrAlloc,
                                                       uint64_t srcOffset,
                                                       uint64_t size,
-                                                      Event *signalEvent);
+                                                      Event *signalEvent,
+                                                      CmdListMemoryCopyParams &memoryCopyParams);
 
     MOCKABLE_VIRTUAL ze_result_t appendMemoryCopyBlitRegion(AlignedAllocationData *srcAllocationData,
                                                             AlignedAllocationData *dstAllocationData,
@@ -263,14 +289,15 @@ struct CommandListCoreFamily : public CommandListImp {
                                                             size_t dstRowPitch, size_t dstSlicePitch,
                                                             const Vec3<size_t> &srcSize, const Vec3<size_t> &dstSize,
                                                             Event *signalEvent,
-                                                            uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents, bool relaxedOrderingDispatch, bool dualStreamCopyOffload);
+                                                            uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents, CmdListMemoryCopyParams &memoryCopyParams, bool dualStreamCopyOffload);
 
     MOCKABLE_VIRTUAL ze_result_t appendMemoryCopyKernel2d(AlignedAllocationData *dstAlignedAllocation, AlignedAllocationData *srcAlignedAllocation,
                                                           Builtin builtin, const ze_copy_region_t *dstRegion,
                                                           uint32_t dstPitch, size_t dstOffset,
                                                           const ze_copy_region_t *srcRegion, uint32_t srcPitch,
                                                           size_t srcOffset, Event *signalEvent,
-                                                          uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents, bool relaxedOrderingDispatch);
+                                                          uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents,
+                                                          bool relaxedOrderingDispatch, bool isStateless, bool isHeapless);
 
     MOCKABLE_VIRTUAL ze_result_t appendMemoryCopyKernel3d(AlignedAllocationData *dstAlignedAllocation, AlignedAllocationData *srcAlignedAllocation,
                                                           Builtin builtin, const ze_copy_region_t *dstRegion,
@@ -278,7 +305,8 @@ struct CommandListCoreFamily : public CommandListImp {
                                                           const ze_copy_region_t *srcRegion, uint32_t srcPitch,
                                                           uint32_t srcSlicePitch, size_t srcOffset,
                                                           Event *signalEvent, uint32_t numWaitEvents,
-                                                          ze_event_handle_t *phWaitEvents, bool relaxedOrderingDispatch);
+                                                          ze_event_handle_t *phWaitEvents, bool relaxedOrderingDispatch,
+                                                          bool isStateless, bool isHeapless);
 
     MOCKABLE_VIRTUAL ze_result_t appendBlitFill(void *ptr, const void *pattern,
                                                 size_t patternSize, size_t size,
@@ -312,10 +340,11 @@ struct CommandListCoreFamily : public CommandListImp {
                                           Event *signalEvent,
                                           CmdListKernelLaunchParams &launchParams);
 
-    void appendWaitOnSingleEvent(Event *event, CommandToPatchContainer *outWaitCmds, bool relaxedOrderingAllowed, bool dualStreamCopyOffload, CommandToPatch::CommandType storedSemaphore);
+    template <typename PatchSemaphoreType>
+    void appendWaitOnSingleEvent(Event *event, CommandToPatchContainer *outWaitCmds, bool relaxedOrderingAllowed, bool dualStreamCopyOffload);
 
     void appendSdiInOrderCounterSignalling(uint64_t baseGpuVa, uint64_t signalValue, bool copyOffloadOperation);
-    void appendSignalAggregatedEventAtomic(Event &event);
+    void appendSignalAggregatedEventAtomic(Event &event, bool dualStreamCopyOffload);
 
     ze_result_t prepareIndirectParams(const ze_group_count_t *threadGroupDimensions);
     void updateStreamPropertiesForRegularCommandLists(Kernel &kernel, bool isCooperative, const ze_group_count_t &threadGroupDimensions, bool isIndirect);
@@ -341,7 +370,6 @@ struct CommandListCoreFamily : public CommandListImp {
     void writeKernelTimestamp(uint64_t baseAddr, Event *event, CommandToPatchContainer *outTimeStampSyncCmds, size_t offset, bool maskLsb, bool workloadPartition, bool copyOperation, bool isGlobalTimestamp);
     void appendEventForProfiling(Event *event, CommandToPatchContainer *outTimeStampSyncCmds, bool beforeWalker, bool skipBarrierForEndProfiling, bool skipAddingEventToResidency, bool copyOperation);
     void appendEventForProfilingCopyCommand(Event *event, bool beforeWalker);
-    void appendSignalEventPostWalker(Event *event, void **syncCmdBuffer, CommandToPatchContainer *outTimeStampSyncCmds, bool skipBarrierForEndProfiling, bool skipAddingEventToResidency, bool copyOperation);
     void programStateBaseAddress(NEO::CommandContainer &container, bool useSbaProperties);
     virtual void programStateBaseAddressHook(size_t cmdBufferOffset, bool surfaceBaseAddressModify) {
     }
@@ -350,13 +378,13 @@ struct CommandListCoreFamily : public CommandListImp {
     void appendMultiTileBarrier(NEO::Device &neoDevice);
     void appendDispatchOffsetRegister(bool workloadPartitionEvent, bool beforeProfilingCmds);
     size_t estimateBufferSizeMultiTileBarrier(const NEO::RootDeviceEnvironment &rootDeviceEnvironment);
-    uint64_t getInputBufferSize(NEO::ImageType imageType, uint32_t bufferRowPitch, uint32_t bufferSlicePitch, const ze_image_region_t *region);
+    uint64_t getInputBufferSize(NEO::ImageType imageType, uint32_t bufferRowPitch, uint32_t bufferSlicePitch, const ze_image_region_t *region, size_t pixelSize);
     MOCKABLE_VIRTUAL AlignedAllocationData getAlignedAllocationData(Device *device, bool sharedSystemEnabled, const void *buffer, uint64_t bufferSize, bool hostCopyAllowed, bool copyOffload);
     size_t getAllocationOffsetForAppendBlitFill(void *ptr, NEO::GraphicsAllocation &gpuAllocation);
     uint32_t getRegionOffsetForAppendMemoryCopyBlitRegion(AlignedAllocationData *allocationData);
     void handlePostSubmissionState();
 
-    MOCKABLE_VIRTUAL void setAdditionalBlitProperties(NEO::BlitProperties &blitProperties, Event *signalEvent, bool useAdditionalTimestamp);
+    MOCKABLE_VIRTUAL void setAdditionalBlitProperties(NEO::BlitProperties &blitProperties, Event *signalEvent, uint64_t forceAggregatedEventIncValue, bool useAdditionalTimestamp);
 
     void setupFillKernelArguments(size_t baseOffset,
                                   size_t patternSize,
@@ -380,7 +408,6 @@ struct CommandListCoreFamily : public CommandListImp {
     void dispatchEventPostSyncOperation(Event *event, void **syncCmdBuffer, CommandToPatchContainer *outListCommands, uint32_t value, bool omitFirstOperation, bool useMax, bool useLastPipeControl,
                                         bool skipPartitionOffsetProgramming, bool copyOperation);
 
-    bool isAllocationImported(NEO::GraphicsAllocation *gpuAllocation, NEO::SVMAllocsManager *svmManager) const;
     static constexpr bool checkIfAllocationImportedRequired();
 
     bool isKernelUncachedMocsRequired(bool kernelState);
@@ -415,20 +442,36 @@ struct CommandListCoreFamily : public CommandListImp {
     bool isDeviceToHostBcsCopy(NEO::GraphicsAllocation *srcAllocation, NEO::GraphicsAllocation *dstAllocation, bool copyEngineOperation) const;
     bool singleEventPacketRequired(bool inputSinglePacketEventRequest) const;
     void programEventL3Flush(Event *event);
-    virtual ze_result_t flushInOrderCounterSignal(bool waitOnInOrderCounterRequired) { return ZE_RESULT_SUCCESS; };
-    bool isCopyOffloadAllowed(const NEO::GraphicsAllocation *srcAllocation, const NEO::GraphicsAllocation *dstAllocation) const;
+    virtual ze_result_t flushInOrderCounterSignal() { return ZE_RESULT_SUCCESS; };
+    bool isCopyOffloadAllowed(const NEO::GraphicsAllocation *srcAllocation, const NEO::GraphicsAllocation *dstAllocation, bool imageToBuffer) const;
     bool isSharedSystemEnabled() const;
+    void emitMemAdviseForSystemCopy(const AlignedAllocationData &allocationStruct, size_t size);
     void setAdditionalKernelLaunchParams(CmdListKernelLaunchParams &launchParams, Kernel &kernel) const;
     void dispatchInOrderPostOperationBarrier(Event *signalOperation, bool dcFlushRequired, bool copyOperation);
     NEO::GraphicsAllocation *getDeviceCounterAllocForResidency(NEO::GraphicsAllocation *counterDeviceAlloc);
     bool isHighPriorityImmediateCmdList() const;
-    void prefetchKernelMemory(NEO::LinearStream &cmdStream, const Kernel &kernel, const NEO::GraphicsAllocation *iohAllocation, size_t iohOffset, CommandToPatchContainer *outListCommands, uint64_t cmdId);
-    virtual void addKernelIsaMemoryPrefetchPadding(NEO::LinearStream &cmdStream, const Kernel &kernel, uint64_t cmdId) {}
-    virtual void addKernelIndirectDataMemoryPrefetchPadding(NEO::LinearStream &cmdStream, const Kernel &kernel, uint64_t cmdId) {}
+    void prefetchKernelMemory(NEO::LinearStream &cmdStream, const Kernel &kernel, const NEO::GraphicsAllocation *iohAllocation, size_t iohOffset, CommandToPatchContainer *outListCommands,
+                              uint64_t cmdId, size_t estimateSizeForPrefetch);
     virtual uint64_t getPrefetchCmdId() const { return std::numeric_limits<uint64_t>::max(); }
     virtual uint32_t getIohSizeForPrefetch(const Kernel &kernel, uint32_t reserveExtraSpace) const;
-    virtual void ensureCmdBufferSpaceForPrefetch() {}
+    virtual size_t ensureCmdBufferSpaceForPrefetch() { return 0; }
     bool transferDirectionRequiresBcsSplit(NEO::TransferDirection direction) const;
+    std::optional<SWTagScope<GfxFamily>> emplaceSWTagScope(const char *callName);
+    size_t getDefaultMinBcsSplitSize() const;
+
+    template <typename Container>
+    void addResidency(const Container &allocs) {
+        for (auto alloc : allocs) {
+            this->commandContainer.addToResidencyContainer(alloc);
+        }
+    }
+    template <typename... T>
+        requires(std::convertible_to<T, NEO::GraphicsAllocation *> && ...)
+    void addResidency(T... alloc) {
+        (this->commandContainer.addToResidencyContainer(alloc), ...);
+    }
+
+    bool isCopyOffloadForFillOrStagingPreferred() const;
 
     NEO::InOrderPatchCommandsContainer<GfxFamily> inOrderPatchCmds;
 
@@ -441,6 +484,7 @@ struct CommandListCoreFamily : public CommandListImp {
     bool implicitSynchronizedDispatchForCooperativeKernelsAllowed = false;
     bool useAdditionalBlitProperties = false;
     bool isPostImageWriteFlushRequired = false;
+    bool latestFlushIsDualCopyOffload = false;
 };
 
 template <PRODUCT_FAMILY gfxProductFamily>
