@@ -32,8 +32,6 @@
 #include "level_zero/driver_experimental/zex_memory.h"
 #include "level_zero/zer_api.h"
 
-#include <string.h>
-
 namespace NEO {
 enum class AtomicAccessMode : uint32_t;
 } // namespace NEO
@@ -42,7 +40,7 @@ namespace L0 {
 
 ze_result_t ContextImp::destroy() {
     while (driverHandle->svmAllocsManager->getNumDeferFreeAllocs() > 0) {
-        this->driverHandle->svmAllocsManager->freeSVMAllocDeferImpl();
+        this->driverHandle->svmAllocsManager->freeSVMAllocDeferImplBlocking();
     }
     delete this;
 
@@ -68,25 +66,22 @@ ContextImp::ContextImp(DriverHandle *driverHandle) {
     this->driverHandle = static_cast<DriverHandleImp *>(driverHandle);
     this->contextExt = createContextExt(driverHandle);
 
-    bool platformSupportSvmHeapReservation = true;
+    // Determine context settings based on device capabilities.
+    settings.enableSvmHeapReservation = true;
     for (auto &device : this->driverHandle->devices) {
         auto &productHelper = device->getNEODevice()->getProductHelper();
         if (!productHelper.isSvmHeapReservationSupported()) {
-            platformSupportSvmHeapReservation = false;
+            settings.enableSvmHeapReservation = false;
             break;
         }
     }
-    contextSettings.enableSvmHeapReservation = platformSupportSvmHeapReservation;
-
-    bool useOpaqueHandle = true;
-    for (auto &device : this->driverHandle->devices) {
-        auto &productHelper = device->getNEODevice()->getProductHelper();
-        if (!productHelper.isPidFdOrSocketForIpcSupported()) {
-            useOpaqueHandle = false;
-            break;
-        }
-    }
-    contextSettings.enablePidfdOrSockets = useOpaqueHandle;
+    // NOTE: Calling a virtual method in a constructor is discouraged, but it's safe in
+    // this case because derived classes do not override this method. If derived class
+    // needs to override, then derived class ctor must call overriden function (example
+    // ContextImpDerived::isOpaqueHandleSupported) to enforce correct behavior.
+    // Using Class::method syntax to make it explicit which class method is called and
+    // avoid clang-tidy warning.
+    settings.useOpaqueHandle = ContextImp::isOpaqueHandleSupported(&settings.handleType);
 }
 
 ContextImp::~ContextImp() {
@@ -505,15 +500,15 @@ NEO::UsmMemAllocPool *ContextImp::getUsmPoolOwningPtr(const void *ptr, NEO::SvmA
     return usmPool;
 }
 
-bool ContextImp::tryFreeViaPooling(const void *ptr, NEO::SvmAllocationData *svmData, NEO::UsmMemAllocPool *usmPool) {
+bool ContextImp::tryFreeViaPooling(const void *ptr, NEO::SvmAllocationData *svmData, NEO::UsmMemAllocPool *usmPool, bool blocking) {
     if (usmPool) {
         if (svmData->device && svmData->device->getUsmMemAllocPoolsManager()) {
-            return svmData->device->getUsmMemAllocPoolsManager()->freeSVMAlloc(ptr, false);
+            return svmData->device->getUsmMemAllocPoolsManager()->freeSVMAlloc(ptr, blocking);
         }
         if (!svmData->device && driverHandle->usmHostMemAllocPoolManager) {
-            return driverHandle->usmHostMemAllocPoolManager->freeSVMAlloc(ptr, false);
+            return driverHandle->usmHostMemAllocPoolManager->freeSVMAlloc(ptr, blocking);
         }
-        [[maybe_unused]] auto status = usmPool->freeSVMAlloc(ptr, false);
+        [[maybe_unused]] auto status = usmPool->freeSVMAlloc(ptr, blocking);
         DEBUG_BREAK_IF(false == status);
         return true;
     }
@@ -569,7 +564,7 @@ ze_result_t ContextImp::freeMem(const void *ptr, bool blocking) {
         this->freePeerAllocations(ptr, blocking, Device::fromHandle(pairDevice.second));
     }
 
-    if (this->tryFreeViaPooling(ptr, allocation, usmPool)) {
+    if (this->tryFreeViaPooling(ptr, allocation, usmPool, blocking)) {
         return ZE_RESULT_SUCCESS;
     }
 
@@ -580,8 +575,8 @@ ze_result_t ContextImp::freeMem(const void *ptr, bool blocking) {
 
 ze_result_t ContextImp::freeMemExt(const ze_memory_free_ext_desc_t *pMemFreeDesc,
                                    void *ptr) {
-
-    if (pMemFreeDesc->freePolicy == ZE_DRIVER_MEMORY_FREE_POLICY_EXT_FLAG_BLOCKING_FREE) {
+    const bool blocking = pMemFreeDesc->freePolicy == ZE_DRIVER_MEMORY_FREE_POLICY_EXT_FLAG_BLOCKING_FREE;
+    if (blocking) {
         return this->freeMem(ptr, true);
     }
     if (pMemFreeDesc->freePolicy == ZE_DRIVER_MEMORY_FREE_POLICY_EXT_FLAG_DEFER_FREE) {
@@ -599,7 +594,7 @@ ze_result_t ContextImp::freeMemExt(const ze_memory_free_ext_desc_t *pMemFreeDesc
             this->freePeerAllocations(ptr, false, Device::fromHandle(pairDevice.second));
         }
 
-        if (this->tryFreeViaPooling(ptr, allocation, usmPool)) {
+        if (this->tryFreeViaPooling(ptr, allocation, usmPool, blocking)) {
             return ZE_RESULT_SUCCESS;
         }
 
@@ -729,7 +724,7 @@ ze_result_t ContextImp::getMemAddressRange(const void *ptr,
         if (usmPool) {
             if (nullptr == usmPool->getPooledAllocationBasePtr(ptr)) {
                 // ptr is within usm pool address space but is not allocated
-                return ZE_RESULT_ERROR_UNKNOWN;
+                return ZE_RESULT_ERROR_ADDRESS_NOT_FOUND;
             }
             if (pBase) {
                 *pBase = usmPool->getPooledAllocationBasePtr(ptr);
@@ -753,7 +748,7 @@ ze_result_t ContextImp::getMemAddressRange(const void *ptr,
 
         return ZE_RESULT_SUCCESS;
     }
-    return ZE_RESULT_ERROR_UNKNOWN;
+    return ZE_RESULT_ERROR_ADDRESS_NOT_FOUND;
 }
 
 ze_result_t ContextImp::closeIpcMemHandle(const void *ptr) {
@@ -761,18 +756,28 @@ ze_result_t ContextImp::closeIpcMemHandle(const void *ptr) {
 }
 
 ze_result_t ContextImp::putIpcMemHandle(ze_ipc_mem_handle_t ipcHandle) {
-    using IpcDataT = IpcMemoryData;
-    IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(ipcHandle.data);
-    std::map<uint64_t, IpcHandleTracking *>::iterator ipcHandleIterator;
-    auto lock = this->driverHandle->lockIPCHandleMap();
-    ipcHandleIterator = this->driverHandle->getIPCHandleMap().find(ipcData.handle);
-    if (ipcHandleIterator != this->driverHandle->getIPCHandleMap().end()) {
-        ipcHandleIterator->second->refcnt -= 1;
-        if (ipcHandleIterator->second->refcnt == 0) {
-            auto *memoryManager = driverHandle->getMemoryManager();
-            memoryManager->closeInternalHandle(ipcData.handle, ipcHandleIterator->second->handleId, ipcHandleIterator->second->alloc);
-            delete ipcHandleIterator->second;
-            this->driverHandle->getIPCHandleMap().erase(ipcData.handle);
+    uint64_t handle = 0;
+    if (settings.useOpaqueHandle) {
+        using IpcDataT = IpcOpaqueMemoryData;
+        IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(ipcHandle.data);
+        handle = ipcData.type == IpcHandleType::fdHandle
+                     ? static_cast<uint64_t>(ipcData.handle.fd)
+                     : ipcData.handle.reserved;
+    } else {
+        using IpcDataT = IpcMemoryData;
+        IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(ipcHandle.data);
+        handle = ipcData.handle;
+    }
+    auto lock = driverHandle->lockIPCHandleMap();
+    auto &ipcMap = driverHandle->getIPCHandleMap();
+    auto ipcIter = ipcMap.find(handle);
+    if (ipcIter != ipcMap.end()) {
+        IpcHandleTracking *trackIPC = ipcIter->second;
+        trackIPC->refcnt -= 1;
+        if (trackIPC->refcnt == 0) {
+            driverHandle->getMemoryManager()->closeInternalHandle(handle, trackIPC->handleId, trackIPC->alloc);
+            delete trackIPC;
+            ipcMap.erase(handle);
         }
     }
     return ZE_RESULT_SUCCESS;
@@ -780,17 +785,19 @@ ze_result_t ContextImp::putIpcMemHandle(ze_ipc_mem_handle_t ipcHandle) {
 
 ze_result_t ContextImp::getIpcHandleFromFd(uint64_t handle, ze_ipc_mem_handle_t *pIpcHandle) {
     std::map<uint64_t, IpcHandleTracking *>::iterator ipcHandleIterator;
-    auto lock = this->driverHandle->lockIPCHandleMap();
-    ipcHandleIterator = this->driverHandle->getIPCHandleMap().find(handle);
-    if (ipcHandleIterator != this->driverHandle->getIPCHandleMap().end()) {
-        if (ipcHandleIterator->second->opaqueIpcHandle) {
+    auto lock = driverHandle->lockIPCHandleMap();
+    auto &ipcMap = driverHandle->getIPCHandleMap();
+    auto ipcIter = ipcMap.find(handle);
+    if (ipcIter != ipcMap.end()) {
+        IpcHandleTracking *trackIPC = ipcIter->second;
+        if (settings.useOpaqueHandle) {
             using IpcDataT = IpcOpaqueMemoryData;
             IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandle->data);
-            ipcData = ipcHandleIterator->second->opaqueData;
+            ipcData = trackIPC->opaqueData;
         } else {
             using IpcDataT = IpcMemoryData;
             IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandle->data);
-            ipcData = ipcHandleIterator->second->ipcData;
+            ipcData = trackIPC->ipcData;
         }
     } else {
         return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
@@ -799,19 +806,19 @@ ze_result_t ContextImp::getIpcHandleFromFd(uint64_t handle, ze_ipc_mem_handle_t
 }
 
 ze_result_t ContextImp::getFdFromIpcHandle(ze_ipc_mem_handle_t ipcHandle, uint64_t *pHandle) {
-    IpcHandleType handleType = IpcHandleType::maxHandle;
-    bool useOpaqueHandle = isOpaqueHandleSupported(&handleType);
     uint64_t handle = 0;
-    if (useOpaqueHandle && handleType == IpcHandleType::fdHandle) {
-        using IpcDataOpaqueT = IpcOpaqueMemoryData;
-        IpcDataOpaqueT &ipcData = *reinterpret_cast<IpcDataOpaqueT *>(ipcHandle.data);
-        memcpy(&handle, &ipcData.handle.fd, sizeof(ipcData.handle.fd));
-    } else if (!useOpaqueHandle) {
+    if (settings.useOpaqueHandle) {
+        if (settings.handleType == IpcHandleType::fdHandle) {
+            using IpcDataOpaqueT = IpcOpaqueMemoryData;
+            IpcDataOpaqueT &ipcData = *reinterpret_cast<IpcDataOpaqueT *>(ipcHandle.data);
+            handle = static_cast<uint64_t>(ipcData.handle.fd);
+        } else {
+            return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
+        }
+    } else {
         using IpcDataT = IpcMemoryData;
         IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(ipcHandle.data);
-        memcpy(&handle, &ipcData.handle, sizeof(ipcData.handle));
-    } else {
-        return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
+        handle = ipcData.handle;
     }
     std::map<uint64_t, IpcHandleTracking *>::iterator ipcHandleIterator;
     auto lock = this->driverHandle->lockIPCHandleMap();
@@ -854,13 +861,11 @@ ze_result_t ContextImp::getIpcMemHandlesImpl(const void *ptr,
         return ZE_RESULT_SUCCESS;
     }
 
-    auto ipcType = InternalIpcMemoryType::deviceUnifiedMemory;
+    uint8_t ipcType = static_cast<uint8_t>(InternalIpcMemoryType::deviceUnifiedMemory);
     if (type == InternalMemoryType::hostUnifiedMemory) {
-        ipcType = InternalIpcMemoryType::hostUnifiedMemory;
+        ipcType = static_cast<uint8_t>(InternalIpcMemoryType::hostUnifiedMemory);
     }
 
-    IpcHandleType handleType = IpcHandleType::maxHandle;
-    bool useOpaqueHandle = isOpaqueHandleSupported(&handleType);
     uint32_t loopCount = numIpcHandles ? *numIpcHandles : 1u;
     for (uint32_t i = 0u; i < loopCount; i++) {
         uint64_t handle = 0;
@@ -871,12 +876,17 @@ ze_result_t ContextImp::getIpcMemHandlesImpl(const void *ptr,
 
         memoryManager->registerIpcExportedAllocation(alloc);
 
-        if (useOpaqueHandle) {
-            IpcOpaqueMemoryData &ipcData = *reinterpret_cast<IpcOpaqueMemoryData *>(pIpcHandles[i].data);
-            setIPCHandleData<IpcOpaqueMemoryData>(alloc, handle, ipcData, reinterpret_cast<uint64_t>(ptr), static_cast<uint8_t>(ipcType), usmPool, handleType);
+        uint64_t ptrAddr = reinterpret_cast<uint64_t>(ptr);
+        if (settings.useOpaqueHandle) {
+            using IpcDataT = IpcOpaqueMemoryData;
+            IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandles[i].data);
+            setIPCHandleData<IpcDataT>(alloc, handle, ipcData, ptrAddr, ipcType,
+                                       usmPool, settings.handleType);
         } else {
-            IpcMemoryData &ipcData = *reinterpret_cast<IpcMemoryData *>(pIpcHandles[i].data);
-            setIPCHandleData<IpcMemoryData>(alloc, handle, ipcData, reinterpret_cast<uint64_t>(ptr), static_cast<uint8_t>(ipcType), usmPool, handleType);
+            using IpcDataT = IpcMemoryData;
+            IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandles[i].data);
+            setIPCHandleData<IpcDataT>(alloc, handle, ipcData, ptrAddr, ipcType,
+                                       usmPool, settings.handleType);
         }
     }
     return ZE_RESULT_SUCCESS;
@@ -1219,6 +1229,33 @@ ze_result_t ContextImp::getAtomicAccessAttribute(ze_device_handle_t hDevice, con
     return ZE_RESULT_SUCCESS;
 }
 
+ze_result_t ContextImp::mapDeviceMemToHost(const void *ptr, void **pptr, void *pNext) {
+
+    if (pNext) {
+        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+    }
+
+    auto allocData = this->driverHandle->svmAllocsManager->getSVMAlloc(ptr);
+    if (!allocData) {
+        return ZE_RESULT_ERROR_INVALID_ARGUMENT;
+    }
+
+    auto gpuAllocation = allocData->gpuAllocations.getDefaultGraphicsAllocation();
+    if (gpuAllocation->isCompressionEnabled()) {
+        return ZE_RESULT_ERROR_INCOMPATIBLE_RESOURCE;
+    }
+
+    auto cpuPtr = this->driverHandle->memoryManager->lockResource(gpuAllocation);
+    if (!cpuPtr) {
+        return ZE_RESULT_ERROR_INCOMPATIBLE_RESOURCE;
+    }
+
+    auto pool = getUsmPoolOwningPtr(ptr, allocData);
+    *pptr = ptrOffset(cpuPtr, pool ? pool->getOffsetInPool(ptr) : 0u);
+
+    return ZE_RESULT_SUCCESS;
+}
+
 ze_result_t ContextImp::createModule(ze_device_handle_t hDevice,
                                      const ze_module_desc_t *desc,
                                      ze_module_handle_t *phModule,
@@ -1309,7 +1346,7 @@ ze_result_t ContextImp::reserveVirtualMem(const void *pStart,
         reserveOnSvmHeap = false;
     }
 
-    reserveOnSvmHeap &= contextSettings.enableSvmHeapReservation;
+    reserveOnSvmHeap &= settings.enableSvmHeapReservation;
     reserveOnSvmHeap &= NEO::debugManager.flags.EnableReservingInSvmRange.get();
 
     if (reserveOnSvmHeap) {
@@ -1556,7 +1593,7 @@ ze_result_t ContextImp::mapVirtualMem(const void *ptr,
     }
 
     if (allocationNode->allocation->getAllocationType() == NEO::AllocationType::buffer) {
-        if (!this->driverHandle->getMemoryManager()->mapPhysicalDeviceMemoryToVirtualMemory(allocationNode->allocation, reinterpret_cast<uint64_t>(ptr), size)) {
+        if (!this->driverHandle->getMemoryManager()->mapPhysicalDeviceMemoryToVirtualMemory(allocationNode->allocation, reinterpret_cast<uint64_t>(ptr), size, &virtualMemoryReservation->flags)) {
             return ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY;
         }
         NEO::SvmAllocationData allocData(allocationNode->allocation->getRootDeviceIndex());
@@ -1651,6 +1688,7 @@ ze_result_t ContextImp::setVirtualMemAccessAttribute(const void *ptr,
     auto lockVirtual = this->driverHandle->getMemoryManager()->lockVirtualMemoryReservationMap();
     virtualMemoryReservation = findSupportedVirtualReservation(ptr, size);
     if (virtualMemoryReservation) {
+        NEO::MemoryFlags flagsBefore = virtualMemoryReservation->flags;
         switch (access) {
         case ZE_MEMORY_ACCESS_ATTRIBUTE_NONE:
             virtualMemoryReservation->flags.readOnly = false;
@@ -1670,6 +1708,17 @@ ze_result_t ContextImp::setVirtualMemAccessAttribute(const void *ptr,
         default:
             return ZE_RESULT_ERROR_INVALID_ENUMERATION;
         }
+        if (flagsBefore != virtualMemoryReservation->flags &&
+            virtualMemoryReservation->mappedAllocations.size() > 0) {
+            std::map<void *, NEO::MemoryMappedRange *>::iterator physicalMapIt;
+            physicalMapIt = virtualMemoryReservation->mappedAllocations.find(const_cast<void *>(ptr));
+            if (physicalMapIt != virtualMemoryReservation->mappedAllocations.end()) {
+                auto allocation = physicalMapIt->second->mappedAllocation.allocation;
+                lockVirtual.unlock();
+                unMapVirtualMem(ptr, size);
+                mapVirtualMem(ptr, size, reinterpret_cast<ze_physical_mem_handle_t>(allocation), 0, access);
+            }
+        }
         return ZE_RESULT_SUCCESS;
     } else {
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
