@@ -132,6 +132,7 @@ ze_result_t EventPool::initialize(DriverHandle *driver, Context *context, uint32
         if (!allocatedMemory) {
             NEO::AllocationProperties allocationProperties{*rootDeviceIndices.begin(), this->eventPoolSize, allocationType, neoDevice->getDeviceBitfield()};
             allocationProperties.alignment = eventAlignment;
+            allocationProperties.flags.uncacheable = neoDevice->getProductHelper().isDcFlushAllowed();
 
             auto memoryManager = driver->getMemoryManager();
             auto graphicsAllocation = memoryManager->allocateGraphicsMemoryWithProperties(allocationProperties);
@@ -148,6 +149,7 @@ ze_result_t EventPool::initialize(DriverHandle *driver, Context *context, uint32
         this->isHostVisibleEventPoolAllocation = true;
         NEO::AllocationProperties allocationProperties{*rootDeviceIndices.begin(), this->eventPoolSize, allocationType, NEO::systemMemoryBitfield};
         allocationProperties.alignment = eventAlignment;
+        allocationProperties.flags.uncacheable = neoDevice->getProductHelper().isDcFlushAllowed();
 
         eventPoolPtr = driver->getMemoryManager()->createMultiGraphicsAllocationInSystemMemoryPool(rootDeviceIndices,
                                                                                                    allocationProperties,
@@ -412,8 +414,6 @@ ze_result_t EventPool::getIpcHandle(ze_ipc_event_pool_handle_t *ipcHandle) {
     }
     memoryManager->registerIpcExportedAllocation(allocation);
 
-    IpcHandleType handleType = IpcHandleType::maxHandle;
-    bool useOpaque = context->isOpaqueHandleSupported(&handleType);
     IpcOpaqueEventPoolData &ipcData = *reinterpret_cast<IpcOpaqueEventPoolData *>(ipcHandle->data);
     ipcData = {};
     ipcData.handle.val = handle;
@@ -426,8 +426,8 @@ ze_result_t EventPool::getIpcHandle(ze_ipc_event_pool_handle_t *ipcHandle) {
     ipcData.isImplicitScalingCapable = isImplicitScalingCapable;
     ipcData.isEventPoolKernelMappedTsFlagSet = isEventPoolKernelMappedTsFlagSet();
     ipcData.isEventPoolTsFlagSet = isEventPoolTimestampFlagSet();
-    if (useOpaque) {
-        ipcData.type = handleType;
+    if (context->settings.useOpaqueHandle) {
+        ipcData.type = context->settings.handleType;
         ipcData.processId = NEO::SysCalls::getCurrentProcessId();
     }
     return ZE_RESULT_SUCCESS;
@@ -457,10 +457,8 @@ ze_result_t EventPool::openEventPoolIpcHandle(const ze_ipc_event_pool_handle_t &
     NEO::MemoryManager::OsHandleData osHandleData{poolData.handle};
 
     uint32_t parentID = 0;
-    IpcHandleType handleType = IpcHandleType::maxHandle;
-    bool useOpaque = context->isOpaqueHandleSupported(&handleType);
     uint32_t shareWithNoNTHandle = 0;
-    if (useOpaque) {
+    if (context->settings.useOpaqueHandle) {
         IpcOpaqueEventPoolData ipcData = *reinterpret_cast<const IpcOpaqueEventPoolData *>(ipcEventPoolHandle.data);
         parentID = ipcData.processId;
         if (NEO::debugManager.flags.EnableShareableWithoutNTHandle.get()) {
@@ -485,10 +483,10 @@ ze_result_t EventPool::openEventPoolIpcHandle(const ze_ipc_event_pool_handle_t &
 
     eventPool->initializeSizeParameters(numDevices, deviceHandlesUsed, *driver, neoDevice->getRootDeviceEnvironment());
     if (eventPool->getEventMaxPackets() != poolData.maxEventPackets) {
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(),
-                           stderr,
-                           "IPC handle max event packets %u does not match context devices max event packet %u\n",
-                           poolData.maxEventPackets, eventPool->getEventMaxPackets());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(),
+                     stderr,
+                     "IPC handle max event packets %u does not match context devices max event packet %u\n",
+                     poolData.maxEventPackets, eventPool->getEventMaxPackets());
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
     }
 
