@@ -114,9 +114,11 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
         auto &gfxCoreHelper = deviceImp->getNEODevice()->getGfxCoreHelper();
         auto surfaceStateSize = static_cast<uint32_t>(gfxCoreHelper.getRenderSurfaceStateSize());
 
-        this->surfaceStateHeapSize = kernelInfo->kernelDescriptor.kernelAttributes.numArgsStateful * surfaceStateSize;
-        DEBUG_BREAK_IF(kernelInfo->kernelDescriptor.kernelAttributes.numArgsStateful != kernelInfo->kernelDescriptor.getBindlessOffsetToSurfaceState().size());
+        this->surfaceStateHeapSize = (kernelInfo->kernelDescriptor.kernelAttributes.numArgsStateful +
+                                      kernelInfo->kernelDescriptor.kernelAttributes.numBindlessImages) *
+                                     surfaceStateSize;
 
+        DEBUG_BREAK_IF(kernelInfo->kernelDescriptor.kernelAttributes.numArgsStateful != kernelInfo->kernelDescriptor.getBindlessOffsetToSurfaceState().size());
         surfaceStateHeapTemplate.reset(new uint8_t[surfaceStateHeapSize]);
     }
 
@@ -379,6 +381,56 @@ ze_result_t KernelImp::getKernelProgramBinary(size_t *kernelSize, char *pKernelB
     return ZE_RESULT_SUCCESS;
 }
 
+ze_result_t KernelImp::getAllocationProperties(uint32_t *pCount, ze_kernel_allocation_exp_properties_t *pAllocationProperties) {
+    uint32_t totalAllocations = 0;
+
+    for (const auto &alloc : getArgumentsResidencyContainer()) {
+        if (alloc) {
+            ++totalAllocations;
+        }
+    }
+
+    totalAllocations += static_cast<uint32_t>(getInternalResidencyContainer().size());
+
+    if (*pCount == 0 || *pCount > totalAllocations) {
+        *pCount = totalAllocations;
+    }
+
+    // If pAllocationProperties is nullptr, then user getting *pCount first and calling second time
+    if (pAllocationProperties == nullptr) {
+        return ZE_RESULT_SUCCESS;
+    }
+
+    auto svmAllocsManager = this->module->getDevice()->getDriverHandle()->getSvmAllocsManager();
+    uint32_t allocIndex = 0;
+
+    auto parseResidencyContainer = [&](const NEO::ResidencyContainer &residencyContainer, bool kernelArgumentsContainer) {
+        for (uint32_t i = 0; allocIndex < *pCount && i < residencyContainer.size(); ++i) {
+            if (!residencyContainer[i]) {
+                continue;
+            }
+
+            pAllocationProperties[allocIndex].base = residencyContainer[i]->getGpuAddress();
+            if (auto svmAlloc = svmAllocsManager->getSVMAlloc(reinterpret_cast<const void *>(residencyContainer[i]->getGpuAddress()))) {
+                pAllocationProperties[allocIndex].size = svmAlloc->size;
+                pAllocationProperties[allocIndex].type = Context::parseUSMType(svmAlloc->memoryType);
+            } else {
+                pAllocationProperties[allocIndex].size = residencyContainer[i]->getUnderlyingBufferSize();
+                pAllocationProperties[allocIndex].type = ZE_MEMORY_TYPE_UNKNOWN;
+            }
+
+            pAllocationProperties[allocIndex].argIndex = kernelArgumentsContainer ? i : std::numeric_limits<uint32_t>::max();
+
+            ++allocIndex;
+        }
+    };
+
+    parseResidencyContainer(getArgumentsResidencyContainer(), true);
+    parseResidencyContainer(getInternalResidencyContainer(), false);
+
+    return ZE_RESULT_SUCCESS;
+}
+
 ze_result_t KernelImp::setArgumentValue(uint32_t argIndex, size_t argSize,
                                         const void *pArgValue) {
     if (argIndex >= privateState.kernelArgHandlers.size()) {
@@ -437,9 +489,9 @@ ze_result_t KernelImp::setGroupSize(uint32_t groupSizeX, uint32_t groupSizeY,
 
     const NEO::KernelDescriptor &kernelDescriptor = getImmutableData()->getDescriptor();
     if (auto maxGroupSize = module->getMaxGroupSize(kernelDescriptor); itemsInGroup > maxGroupSize) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
-                              "Requested work-group size (%lu) exceeds maximum value (%u) for the kernel \"%s\" \n",
-                              itemsInGroup, maxGroupSize, kernelDescriptor.kernelMetadata.kernelName.c_str());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
+                     "Requested work-group size (%lu) exceeds maximum value (%u) for the kernel \"%s\" \n",
+                     itemsInGroup, maxGroupSize, kernelDescriptor.kernelMetadata.kernelName.c_str());
         DEBUG_BREAK_IF(true);
         return ZE_RESULT_ERROR_INVALID_GROUP_SIZE_DIMENSION;
     }
@@ -450,12 +502,12 @@ ze_result_t KernelImp::setGroupSize(uint32_t groupSizeX, uint32_t groupSizeY,
     for (uint32_t i = 0u; i < 3u; i++) {
         if (kernelDescriptor.kernelAttributes.requiredWorkgroupSize[i] != 0 &&
             kernelDescriptor.kernelAttributes.requiredWorkgroupSize[i] != this->privateState.groupSize[i]) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
-                                  "Invalid group size {%d, %d, %d} specified, requiredWorkGroupSize = {%d, %d, %d}\n",
-                                  this->privateState.groupSize[0], this->privateState.groupSize[1], this->privateState.groupSize[2],
-                                  kernelDescriptor.kernelAttributes.requiredWorkgroupSize[0],
-                                  kernelDescriptor.kernelAttributes.requiredWorkgroupSize[1],
-                                  kernelDescriptor.kernelAttributes.requiredWorkgroupSize[2]);
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
+                         "Invalid group size {%d, %d, %d} specified, requiredWorkGroupSize = {%d, %d, %d}\n",
+                         this->privateState.groupSize[0], this->privateState.groupSize[1], this->privateState.groupSize[2],
+                         kernelDescriptor.kernelAttributes.requiredWorkgroupSize[0],
+                         kernelDescriptor.kernelAttributes.requiredWorkgroupSize[1],
+                         kernelDescriptor.kernelAttributes.requiredWorkgroupSize[2]);
             return ZE_RESULT_ERROR_INVALID_GROUP_SIZE_DIMENSION;
         }
     }
@@ -564,7 +616,7 @@ ze_result_t KernelImp::suggestGroupSize(uint32_t globalSizeX, uint32_t globalSiz
 
             CREATE_DEBUG_STRING(str, "Size of SLM (%u) larger than available (%u)\n", this->getSlmTotalSize(), localMemSize);
             driverHandle->setErrorDescription(std::string(str.get()));
-            PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Size of SLM (%u) larger than available (%u)\n", this->getSlmTotalSize(), localMemSize);
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Size of SLM (%u) larger than available (%u)\n", this->getSlmTotalSize(), localMemSize);
             return ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY;
         }
 
@@ -780,7 +832,7 @@ ze_result_t KernelImp::setArgBuffer(uint32_t argIndex, size_t argSize, const voi
     NEO::SvmAllocationData *allocData = nullptr;
     if (argVal != nullptr) {
         const auto requestedAddress = *reinterpret_cast<void *const *>(argVal);
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintL0SetKernelArg.get(), stderr, "set arg buffer index : %u requested address : %p\n", argIndex, requestedAddress);
+        PRINT_STRING(NEO::debugManager.flags.PrintL0SetKernelArg.get(), stderr, "set arg buffer index : %u requested address : %p\n", argIndex, requestedAddress);
         if (argInfo.allocId > 0 &&
             argInfo.allocId < NEO::SvmAllocationData::uninitializedAllocId &&
             requestedAddress == argInfo.value) {
@@ -921,9 +973,16 @@ ze_result_t KernelImp::setArgImage(uint32_t argIndex, size_t argSize, const void
 
             privateState.isBindlessOffsetSet[argIndex] = true;
         } else {
+            if (image->getImplicitArgsAllocation() == nullptr) {
+                auto allocResult = image->allocateImplicitArgsOnDemand();
+                if (allocResult != ZE_RESULT_SUCCESS) {
+                    return allocResult;
+                }
+            }
             privateState.usingSurfaceStateHeap[argIndex] = true;
             auto ssPtr = &getSurfaceStateHeapDataSpan()[getSurfaceStateIndexForBindlessOffset(arg.bindless) * surfaceStateSize];
             image->copySurfaceStateToSSH(ssPtr, 0u, NEO::BindlessImageSlot::image, isMediaBlockImage);
+            image->copySurfaceStateToSSH(ptrOffset(ssPtr, surfaceStateSize), 0u, NEO::BindlessImageSlot::implicitArgs, false);
         }
     } else {
         image->copySurfaceStateToSSH(privateState.surfaceStateHeapData.data(), arg.bindful, NEO::BindlessImageSlot::image, isMediaBlockImage);
@@ -1072,7 +1131,7 @@ NEO::GraphicsAllocation *KernelImp::allocatePrivateMemoryGraphicsAllocation() {
         const auto maxGlobalMemorySize = neoDevice->getRootDevice()->getGlobalMemorySize(static_cast<uint32_t>(neoDevice->getDeviceBitfield().to_ulong()));
         CREATE_DEBUG_STRING(str, "Failed to allocate private surface of %zu bytes, used local memory %zu, max global memory %zu\n", static_cast<size_t>(privateSurfaceSize), usedLocalMemorySize, static_cast<size_t>(maxGlobalMemorySize));
         neoDevice->getRootDeviceEnvironment().executionEnvironment.setErrorDescription(std::string(str.get()));
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, str.get());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, str.get());
     }
 
     return privateMemoryGraphicsAllocation;
@@ -1129,7 +1188,7 @@ ze_result_t KernelImp::initialize(const ze_kernel_desc_t *desc) {
     if (slmInlineSize > 0 && localMemSize < slmInlineSize) {
         CREATE_DEBUG_STRING(str, "Size of SLM (%u) larger than available (%u)\n", slmInlineSize, localMemSize);
         module->getDevice()->getDriverHandle()->setErrorDescription(std::string(str.get()));
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Size of SLM (%u) larger than available (%u)\n", slmInlineSize, localMemSize);
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Size of SLM (%u) larger than available (%u)\n", slmInlineSize, localMemSize);
         return ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY;
     }
 
