@@ -8,6 +8,7 @@
 #include "level_zero/core/source/module/module_imp.h"
 
 #include "shared/source/command_stream/command_stream_receiver.h"
+#include "shared/source/compiler_interface/compiler_interface.h"
 #include "shared/source/compiler_interface/compiler_options.h"
 #include "shared/source/compiler_interface/compiler_options_extra.h"
 #include "shared/source/compiler_interface/compiler_warnings/compiler_warnings.h"
@@ -55,6 +56,8 @@
 
 #include <algorithm>
 #include <memory>
+#include <mutex>
+#include <optional>
 #include <unordered_map>
 
 #define ZE_MODULE_FORMAT_OCLC (ze_module_format_t)3U
@@ -196,7 +199,7 @@ bool ModuleTranslationUnit::processSpecConstantInfo(NEO::CompilerInterface *comp
     if (pConstants) {
         NEO::SpecConstantInfo specConstInfo;
         auto retVal = compilerInterface->getSpecConstantsInfo(*device->getNEODevice(), ArrayRef<const char>(input, inputSize), specConstInfo);
-        if (retVal != NEO::TranslationOutput::ErrorCode::success) {
+        if (retVal != NEO::TranslationErrorCode::success) {
             return false;
         }
         for (uint32_t i = 0; i < pConstants->numConstants; i++) {
@@ -232,7 +235,7 @@ ze_result_t ModuleTranslationUnit::compileGenBinary(NEO::TranslationInput &input
     inputArgs.specializedValues = this->specConstantsValues;
 
     NEO::TranslationOutput compilerOuput = {};
-    NEO::TranslationOutput::ErrorCode compilerErr;
+    NEO::TranslationErrorCode compilerErr;
 
     if (staticLink) {
         compilerErr = compilerInterface->link(*device->getNEODevice(), inputArgs, compilerOuput);
@@ -243,7 +246,7 @@ ze_result_t ModuleTranslationUnit::compileGenBinary(NEO::TranslationInput &input
     this->updateBuildLog(compilerOuput.frontendCompilerLog);
     this->updateBuildLog(compilerOuput.backendCompilerLog);
 
-    if (NEO::TranslationOutput::ErrorCode::success != compilerErr) {
+    if (NEO::TranslationErrorCode::success != compilerErr) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_MODULE_BUILD_FAILURE;
     }
@@ -345,12 +348,12 @@ ze_result_t ModuleTranslationUnit::createFromNativeBinary(const char *input, siz
                                                        decodeErrors, decodeWarnings);
     const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
     if (decodeWarnings.empty() == false) {
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeWarnings.c_str());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeWarnings.c_str());
     }
     if (singleDeviceBinary.intermediateRepresentation.empty() && singleDeviceBinary.deviceBinary.empty()) {
         CREATE_DEBUG_STRING(str, "%s\n", decodeErrors.c_str());
         driverHandle->setErrorDescription(std::string(str.get()));
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeErrors.c_str());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeErrors.c_str());
         return ZE_RESULT_ERROR_MODULE_BUILD_FAILURE;
     } else {
         this->irBinary = makeCopy(reinterpret_cast<const char *>(singleDeviceBinary.intermediateRepresentation.begin()), singleDeviceBinary.intermediateRepresentation.size());
@@ -386,7 +389,7 @@ ze_result_t ModuleTranslationUnit::createFromNativeBinary(const char *input, siz
     }
 
     if (nullptr == this->unpackedDeviceBinary) {
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", NEO::CompilerWarnings::recompiledFromIr.data());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", NEO::CompilerWarnings::recompiledFromIr.data());
         if (!shouldSuppressRebuildWarning) {
             updateBuildLog(NEO::CompilerWarnings::recompiledFromIr.str());
         }
@@ -419,13 +422,13 @@ ze_result_t ModuleTranslationUnit::processUnpackedBinary() {
     auto &gfxCoreHelper = device->getGfxCoreHelper();
     std::tie(decodeError, singleDeviceBinaryFormat) = NEO::decodeSingleDeviceBinary(programInfo, binary, decodeErrors, decodeWarnings, gfxCoreHelper);
     if (decodeWarnings.empty() == false) {
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeWarnings.c_str());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeWarnings.c_str());
     }
 
     if (NEO::DecodeError::success != decodeError) {
         CREATE_DEBUG_STRING(str, "%s\n", decodeErrors.c_str());
         driverHandle->setErrorDescription(std::string(str.get()));
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeErrors.c_str());
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeErrors.c_str());
         return ZE_RESULT_ERROR_MODULE_BUILD_FAILURE;
     }
 
@@ -448,8 +451,8 @@ ze_result_t ModuleTranslationUnit::processUnpackedBinary() {
     if (slmNeeded > slmAvailable) {
         CREATE_DEBUG_STRING(str, "Size of SLM (%u) larger than available (%u)\n", static_cast<uint32_t>(slmNeeded), static_cast<uint32_t>(slmAvailable));
         driverHandle->setErrorDescription(std::string(str.get()));
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Size of SLM (%u) larger than available (%u)\n",
-                           static_cast<uint32_t>(slmNeeded), static_cast<uint32_t>(slmAvailable));
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Size of SLM (%u) larger than available (%u)\n",
+                     static_cast<uint32_t>(slmNeeded), static_cast<uint32_t>(slmAvailable));
         return ZE_RESULT_ERROR_MODULE_BUILD_FAILURE;
     }
 
@@ -571,6 +574,10 @@ ModuleImp::~ModuleImp() {
         auto neoDevice = this->device->getNEODevice();
         neoDevice->getIsaPoolAllocator().freeSharedIsaAllocation(this->sharedIsaAllocation.release());
     }
+    if (this->kernelsIsaParentRegion) {
+        DEBUG_BREAK_IF(this->device->getNEODevice()->getMemoryManager() == nullptr);
+        this->device->getNEODevice()->getMemoryManager()->freeGraphicsMemory(this->kernelsIsaParentRegion);
+    }
 }
 
 NEO::Zebin::Debug::Segments ModuleImp::getZebinSegments() {
@@ -633,7 +640,8 @@ ze_result_t ModuleImp::initialize(const ze_module_desc_t *desc, NEO::Device *neo
     linkageSuccessful &= populateHostGlobalSymbolsMap(this->translationUnit->programInfo.globalsDeviceToHostNameMap);
     this->updateBuildLog(neoDevice);
 
-    if ((this->isFullyLinked && this->type == ModuleType::user) || (this->sharedIsaAllocation && this->type == ModuleType::builtin)) {
+    if ((this->isFullyLinked && this->type == ModuleType::user) ||
+        ((this->sharedIsaAllocation || this->kernelsIsaParentRegion) && this->type == ModuleType::builtin)) {
         this->transferIsaSegmentsToAllocation(neoDevice, nullptr);
 
         if (device->getL0Debugger()) {
@@ -652,16 +660,30 @@ void ModuleImp::transferIsaSegmentsToAllocation(NEO::Device *neoDevice, const NE
     const auto &productHelper = neoDevice->getProductHelper();
     auto &rootDeviceEnvironment = neoDevice->getRootDeviceEnvironment();
 
-    if (this->sharedIsaAllocation && this->kernelImmData.size()) {
+    if ((this->sharedIsaAllocation || this->kernelsIsaParentRegion) && this->kernelImmData.size()) {
         if (this->kernelImmData[0]->isIsaCopiedToAllocation()) {
             return;
         }
 
-        const auto isaBufferSize = this->sharedIsaAllocation->getSize();
+        NEO::GraphicsAllocation *moduleAllocation = nullptr;
+        size_t moduleOffset = 0;
+        size_t isaBufferSize = 0;
+        std::optional<std::unique_lock<std::mutex>> lock;
+
+        if (this->sharedIsaAllocation) {
+            moduleAllocation = this->sharedIsaAllocation->getGraphicsAllocation();
+            moduleOffset = this->sharedIsaAllocation->getOffset();
+            isaBufferSize = this->sharedIsaAllocation->getSize();
+            lock = this->sharedIsaAllocation->obtainSharedAllocationLock();
+        } else {
+            moduleAllocation = this->kernelsIsaParentRegion;
+            moduleOffset = 0;
+            isaBufferSize = this->kernelsIsaParentRegion->getUnderlyingBufferSize();
+        }
+
         DEBUG_BREAK_IF(isaBufferSize == 0);
         auto isaBuffer = std::vector<std::byte>(isaBufferSize);
         std::memset(isaBuffer.data(), 0x0, isaBufferSize);
-        auto moduleOffset = sharedIsaAllocation->getOffset();
         for (auto &data : this->kernelImmData) {
             DEBUG_BREAK_IF(data->isIsaCopiedToAllocation());
             data->getIsaGraphicsAllocation()->setAubWritable(true, std::numeric_limits<uint32_t>::max());
@@ -671,8 +693,6 @@ void ModuleImp::transferIsaSegmentsToAllocation(NEO::Device *neoDevice, const NE
             auto isaOffset = data->getIsaOffsetInParentAllocation() - moduleOffset;
             memcpy_s(isaBuffer.data() + isaOffset, isaBufferSize - isaOffset, kernelHeapPtr, kernelHeapSize);
         }
-        auto moduleAllocation = this->sharedIsaAllocation->getGraphicsAllocation();
-        auto lock = this->sharedIsaAllocation->obtainSharedAllocationLock();
         NEO::MemoryTransferHelper::transferMemoryToAllocation(productHelper.isBlitCopyRequiredForLocalMemory(rootDeviceEnvironment, *moduleAllocation),
                                                               *neoDevice,
                                                               moduleAllocation,
@@ -887,7 +907,7 @@ ze_result_t ModuleImp::setIsaGraphicsAllocations() {
         DEBUG_BREAK_IF(kernelInfo->heapInfo.kernelHeapSize == 0lu);
         DEBUG_BREAK_IF(!kernelInfo->heapInfo.pKernelHeap);
         auto chunkOffset = kernelsIsaTotalSize;
-        auto chunkSize = this->computeKernelIsaAllocationAlignedSizeWithPadding(kernelInfo->heapInfo.kernelHeapSize, ((i + 1) == kernelsCount));
+        auto chunkSize = NEO::KernelHelper::computeKernelIsaAllocationAlignedSizeWithPadding(*this->device->getNEODevice(), kernelInfo->heapInfo.kernelHeapSize, ((i + 1) == kernelsCount));
         kernelsIsaTotalSize += chunkSize;
         kernelsChunks[i] = {chunkOffset, chunkSize};
     }
@@ -907,6 +927,19 @@ ze_result_t ModuleImp::setIsaGraphicsAllocations() {
             this->kernelImmData[i]->setIsaSubAllocationOffset(this->sharedIsaAllocation->getOffset() + isaOffset);
             this->kernelImmData[i]->setIsaSubAllocationSize(isaSize);
         }
+    } else if (debuggerDisabled) {
+        if (auto allocation = this->allocateKernelsIsaMemory(kernelsIsaTotalSize); allocation == nullptr) {
+            return ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY;
+        } else {
+            this->kernelsIsaParentRegion = allocation;
+        }
+
+        for (auto i = 0lu; i < kernelsCount; i++) {
+            auto [isaOffset, isaSize] = kernelsChunks[i];
+            this->kernelImmData[i]->setIsaParentAllocation(this->kernelsIsaParentRegion);
+            this->kernelImmData[i]->setIsaSubAllocationOffset(isaOffset);
+            this->kernelImmData[i]->setIsaSubAllocationSize(isaSize);
+        }
     } else {
         for (auto i = 0lu; i < kernelsCount; i++) {
             auto kernelInfo = this->translationUnit->programInfo.kernelInfos[i];
@@ -920,13 +953,6 @@ ze_result_t ModuleImp::setIsaGraphicsAllocations() {
     return ZE_RESULT_SUCCESS;
 }
 
-size_t ModuleImp::computeKernelIsaAllocationAlignedSizeWithPadding(size_t isaSize, bool lastKernel) {
-    auto isaPadding = lastKernel ? this->device->getGfxCoreHelper().getPaddingForISAAllocation() : 0u;
-    auto kernelStartPointerAlignment = this->device->getGfxCoreHelper().getKernelIsaPointerAlignment();
-    auto isaAllocationSize = alignUp(isaPadding + isaSize, kernelStartPointerAlignment);
-    return isaAllocationSize;
-}
-
 NEO::GraphicsAllocation *ModuleImp::allocateKernelsIsaMemory(size_t size) {
     auto allocType = (this->type == ModuleType::builtin ? NEO::AllocationType::kernelIsaInternal : NEO::AllocationType::kernelIsa);
     auto neoDevice = this->device->getNEODevice();
@@ -1272,7 +1298,7 @@ ze_result_t ModuleImp::getFunctionPointer(const char *pFunctionName, void **pfnF
         if (!this->isFunctionSymbolExportEnabled) {
             CREATE_DEBUG_STRING(str, "Function Pointers Not Supported Without Compiler flag %s\n", BuildOptions::enableLibraryCompile.str().c_str());
             driverHandle->setErrorDescription(std::string(str.get()));
-            PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Function Pointers Not Supported Without Compiler flag %s\n", BuildOptions::enableLibraryCompile.str().c_str());
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Function Pointers Not Supported Without Compiler flag %s\n", BuildOptions::enableLibraryCompile.str().c_str());
             return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
         }
         return ZE_RESULT_ERROR_INVALID_FUNCTION_NAME;
@@ -1300,7 +1326,7 @@ ze_result_t ModuleImp::getGlobalPointer(const char *pGlobalName, size_t *pSize,
             if (!this->isGlobalSymbolExportEnabled) {
                 CREATE_DEBUG_STRING(str, "Global Pointers Not Supported Without Compiler flag %s\n", BuildOptions::enableGlobalVariableSymbols.str().c_str());
                 driverHandle->setErrorDescription(std::string(str.get()));
-                PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Global Pointers Not Supported Without Compiler flag %s\n", BuildOptions::enableGlobalVariableSymbols.str().c_str());
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Global Pointers Not Supported Without Compiler flag %s\n", BuildOptions::enableGlobalVariableSymbols.str().c_str());
                 return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
             }
             driverHandle->clearErrorDescription();
@@ -1372,8 +1398,8 @@ void ModuleImp::checkIfPrivateMemoryPerDispatchIsNeeded() {
         auto globalMemorySize = neoDevice->getRootDevice()->getGlobalMemorySize(static_cast<uint32_t>(deviceBitfield.to_ulong()));
         auto numSubDevices = deviceBitfield.count();
         this->allocatePrivateMemoryPerDispatch = modulePrivateMemorySize * numSubDevices > globalMemorySize;
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Private Memory Per Dispatch %d for modulePrivateMemorySize %zu subDevices %zu globalMemorySize %" PRIu64 "\n",
-                           this->allocatePrivateMemoryPerDispatch, modulePrivateMemorySize, numSubDevices, globalMemorySize);
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Private Memory Per Dispatch %d for modulePrivateMemorySize %zu subDevices %zu globalMemorySize %" PRIu64 "\n",
+                     this->allocatePrivateMemoryPerDispatch, modulePrivateMemorySize, numSubDevices, globalMemorySize);
     }
 }
 
@@ -1557,7 +1583,7 @@ ze_result_t ModuleImp::performDynamicLink(uint32_t numModules,
             if (functionSymbolExportEnabledCounter == 0) {
                 CREATE_DEBUG_STRING(str, "Dynamic Link Not Supported Without Compiler flag %s\n", BuildOptions::enableLibraryCompile.str().c_str());
                 driverHandle->setErrorDescription(std::string(str.get()));
-                PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Dynamic Link Not Supported Without Compiler flag %s\n", BuildOptions::enableLibraryCompile.str().c_str());
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Dynamic Link Not Supported Without Compiler flag %s\n", BuildOptions::enableLibraryCompile.str().c_str());
             }
             return ZE_RESULT_ERROR_MODULE_LINK_FAILURE;
         }
@@ -1572,6 +1598,22 @@ ze_result_t ModuleImp::performDynamicLink(uint32_t numModules,
         NEO::KernelDescriptorMapT nameToKernelDescriptor;
         for (auto i = 0u; i < numModules; i++) {
             auto moduleId = static_cast<ModuleImp *>(Module::fromHandle(phModules[i]));
+
+            for (auto &data : moduleId->kernelImmData) {
+                for (uint32_t j = 0; j < numModules; ++j) {
+                    if (i == j) {
+                        continue;
+                    }
+                    auto moduleIdLinked = static_cast<ModuleImp *>(Module::fromHandle(phModules[j]));
+                    if (moduleIdLinked->translationUnit->getGlobalVarBufferGA()) {
+                        data->getResidencyContainer().push_back(moduleIdLinked->translationUnit->getGlobalVarBufferGA());
+                    }
+                    if (moduleIdLinked->translationUnit->getGlobalConstBufferGA()) {
+                        data->getResidencyContainer().push_back(moduleIdLinked->translationUnit->getGlobalConstBufferGA());
+                    }
+                }
+            }
+
             auto &programInfo = moduleId->translationUnit->programInfo;
 
             auto toPtrVec = [](auto &inVec, auto &outPtrVec) {
@@ -1783,10 +1825,13 @@ bool moveBuildOption(std::string &dstOptionsSet, std::string &srcOptionSet, NEO:
 }
 
 NEO::GraphicsAllocation *ModuleImp::getKernelsIsaParentAllocation() const {
-    if (!sharedIsaAllocation) {
-        return nullptr;
+    if (sharedIsaAllocation) {
+        return sharedIsaAllocation->getGraphicsAllocation();
     }
-    return sharedIsaAllocation->getGraphicsAllocation();
+    if (kernelsIsaParentRegion) {
+        return kernelsIsaParentRegion;
+    }
+    return nullptr;
 }
 
 size_t ModuleImp::getIsaAllocationPageSize() const {
