@@ -7,6 +7,7 @@
 
 #include "level_zero/experimental/source/graph/graph.h"
 
+#include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/helpers/gfx_core_helper.h"
 
 #include "level_zero/core/source/cmdlist/cmdlist.h"
@@ -14,6 +15,7 @@
 #include "level_zero/core/source/device/device.h"
 #include "level_zero/core/source/event/event.h"
 #include "level_zero/core/source/kernel/kernel_imp.h"
+#include "level_zero/driver_experimental/zex_cmdlist.h"
 
 #include <unordered_map>
 
@@ -96,7 +98,7 @@ auto getOptionalData(ContainerT &container) {
 }
 
 void handleExternalCbEvent(L0::Event *event, ExternalCbEventInfoContainer &container) {
-    if (event && event->isGraphExternalEvent()) {
+    if (event && event->isExternalEvent()) {
         container.addCbEventInfo(event, event->getInOrderExecInfo(), event->getInOrderExecBaseSignalValue(), event->getInOrderAllocationOffset());
     }
 }
@@ -358,6 +360,9 @@ Closure<CaptureApi::zeCommandListAppendLaunchKernelWithArguments>::IndirectArgs:
     UNRECOVERABLE_IF(result != ZE_RESULT_SUCCESS);
 
     auto kernel = static_cast<KernelImp *>(Kernel::fromHandle(apiArgs.kernelHandle));
+    result = CommandList::setKernelState(kernel, apiArgs.groupSizes, apiArgs.pArguments);
+    UNRECOVERABLE_IF(result != ZE_RESULT_SUCCESS);
+
     this->capturedKernel = kernel->makeDependentClone();
 }
 
@@ -372,6 +377,56 @@ ze_result_t Closure<CaptureApi::zeCommandListAppendLaunchKernelWithArguments>::i
     return result;
 }
 
+Closure<CaptureApi::zexCommandListAppendMemoryCopyWithParameters>::IndirectArgs::IndirectArgs(const ApiArgs &apiArgs, ClosureExternalStorage &externalStorage) : IndirectArgsWithWaitEvents(apiArgs, externalStorage) {
+    this->pNext = nullptr;
+
+    auto result = CommandList::cloneAppendMemoryCopyExtensions(reinterpret_cast<const ze_base_desc_t *>(apiArgs.pNext), this->pNext);
+    UNRECOVERABLE_IF(result != ZE_RESULT_SUCCESS);
+}
+
+Closure<CaptureApi::zexCommandListAppendMemoryCopyWithParameters>::IndirectArgs::~IndirectArgs() {
+    CommandList::freeClonedAppendMemoryCopyExtensions(this->pNext);
+}
+
+ze_result_t Closure<CaptureApi::zexCommandListAppendMemoryCopyWithParameters>::instantiateTo(L0::CommandList &executionTarget, ClosureExternalStorage &externalStorage, ExternalCbEventInfoContainer &externalCbEventStorage) const {
+    auto result = zexCommandListAppendMemoryCopyWithParameters(&executionTarget, apiArgs.dstptr, apiArgs.srcptr, apiArgs.size, indirectArgs.pNext, apiArgs.numWaitEvents, externalStorage.getEventsList(indirectArgs.waitEvents), apiArgs.hSignalEvent);
+    handleExternalCbEvent(L0::Event::fromHandle(apiArgs.hSignalEvent), externalCbEventStorage);
+    return result;
+}
+
+Closure<CaptureApi::zexCommandListAppendMemoryFillWithParameters>::IndirectArgs::IndirectArgs(const ApiArgs &apiArgs, ClosureExternalStorage &externalStorage) : IndirectArgsWithWaitEvents(apiArgs, externalStorage) {
+    pattern.resize(apiArgs.patternSize);
+    memcpy_s(pattern.data(), pattern.size(), apiArgs.pattern, apiArgs.patternSize);
+
+    this->pNext = nullptr;
+
+    auto result = CommandList::cloneAppendMemoryCopyExtensions(reinterpret_cast<const ze_base_desc_t *>(apiArgs.pNext), this->pNext);
+    UNRECOVERABLE_IF(result != ZE_RESULT_SUCCESS);
+}
+
+Closure<CaptureApi::zexCommandListAppendMemoryFillWithParameters>::IndirectArgs::~IndirectArgs() {
+    CommandList::freeClonedAppendMemoryCopyExtensions(this->pNext);
+}
+
+ze_result_t Closure<CaptureApi::zexCommandListAppendMemoryFillWithParameters>::instantiateTo(L0::CommandList &executionTarget, ClosureExternalStorage &externalStorage, ExternalCbEventInfoContainer &externalCbEventStorage) const {
+    auto result = zexCommandListAppendMemoryFillWithParameters(&executionTarget, apiArgs.ptr, getOptionalData(indirectArgs.pattern), apiArgs.patternSize, apiArgs.size, indirectArgs.pNext, apiArgs.hSignalEvent, apiArgs.numWaitEvents, externalStorage.getEventsList(indirectArgs.waitEvents));
+    handleExternalCbEvent(L0::Event::fromHandle(apiArgs.hSignalEvent), externalCbEventStorage);
+    return result;
+}
+
+ze_result_t Closure<CaptureApi::zeCommandListAppendHostFunction>::instantiateTo(L0::CommandList &executionTarget, ClosureExternalStorage &externalStorage, ExternalCbEventInfoContainer &externalCbEventStorage) const {
+    auto result = zeCommandListAppendHostFunction(&executionTarget, apiArgs.pHostFunction, apiArgs.pUserData, apiArgs.pNext, apiArgs.hSignalEvent, apiArgs.numWaitEvents, externalStorage.getEventsList(indirectArgs.waitEvents));
+    handleExternalCbEvent(L0::Event::fromHandle(apiArgs.hSignalEvent), externalCbEventStorage);
+    return result;
+}
+
+ExecutableGraph::ExecutableGraph() {
+    int32_t overrideDisablePatchingPreamble = NEO::debugManager.flags.ForceDisableGraphPatchPreamble.get();
+    if (overrideDisablePatchingPreamble != -1) {
+        this->usePatchingPreamble = (overrideDisablePatchingPreamble == 0);
+    }
+}
+
 ExecutableGraph::~ExecutableGraph() = default;
 
 L0::CommandList *ExecutableGraph::allocateAndAddCommandListSubmissionNode() {
@@ -398,15 +453,24 @@ ze_result_t ExecutableGraph::instantiateFrom(Graph &graph, const GraphInstatiate
     std::unordered_map<Graph *, ExecutableGraph *> executableSubGraphMap;
     executableSubGraphMap.reserve(graph.getSubgraphs().size());
     this->subGraphs.reserve(graph.getSubgraphs().size());
-    for (auto &srcSubgraph : graph.getSubgraphs()) {
+
+    auto getExecutableSubgraph = [&](Graph *srcSubgraph, ze_result_t &err) -> ExecutableGraph * {
+        err = ZE_RESULT_SUCCESS;
+        auto alreadyInstantiated = executableSubGraphMap.find(srcSubgraph);
+        if (alreadyInstantiated != executableSubGraphMap.end()) {
+            return alreadyInstantiated->second;
+        }
+
         auto execSubGraph = std::make_unique<ExecutableGraph>();
+        auto ret = execSubGraph.get();
         err = execSubGraph->instantiateFrom(*srcSubgraph, settings);
         if (err != ZE_RESULT_SUCCESS) {
-            return err;
+            return nullptr;
         }
         executableSubGraphMap[srcSubgraph] = execSubGraph.get();
         this->subGraphs.push_back(std::move(execSubGraph));
-    }
+        return ret;
+    };
 
     if (graph.empty() == false) {
         L0::CommandList *currCmdList = nullptr;
@@ -433,18 +497,20 @@ ze_result_t ExecutableGraph::instantiateFrom(Graph &graph, const GraphInstatiate
 
             auto *forkTarget = graph.getJoinedForkTarget(cmdId);
             if (nullptr != forkTarget) {
-                auto execSubGraph = executableSubGraphMap.find(forkTarget);
-                UNRECOVERABLE_IF(executableSubGraphMap.end() == execSubGraph);
+                auto execSubGraph = getExecutableSubgraph(forkTarget, err);
+                if (err != ZE_RESULT_SUCCESS) {
+                    return err;
+                }
 
                 if (settings.forkPolicy == GraphInstatiateSettings::ForkPolicySplitLevels) {
                     // interleave
                     currCmdList->close();
                     currCmdList = nullptr;
-                    this->addSubGraphSubmissionNode(execSubGraph->second);
+                    this->addSubGraphSubmissionNode(execSubGraph);
                 } else {
                     // submit after current
                     UNRECOVERABLE_IF(settings.forkPolicy != GraphInstatiateSettings::ForkPolicyMonolythicLevels)
-                    this->addSubGraphSubmissionNode(execSubGraph->second);
+                    this->addSubGraphSubmissionNode(execSubGraph);
                 }
             }
         }
@@ -468,7 +534,9 @@ ze_result_t ExecutableGraph::execute(L0::CommandList *executionTarget, void *pNe
         }
         executionTarget->appendSignalEvent(hSignalEvent, false);
     } else {
-        this->externalCbEventStorage.attachExternalCbEventsToExecutableGraph();
+        if (this->externalCbEventStorage.externalCbEventsPresent()) {
+            this->externalCbEventStorage.attachExternalCbEventsToExecutableGraph();
+        }
         L0::CommandList *const myLastCommandList = this->myCommandLists.rbegin()->get();
         {
             // first submission node
@@ -478,7 +546,7 @@ ze_result_t ExecutableGraph::execute(L0::CommandList *executionTarget, void *pNe
             auto currSignalEvent = (myLastCommandList == *cmdList) ? hSignalEvent : nullptr;
 
             ze_command_list_handle_t hCmdList = *cmdList;
-            executionTarget->setPatchingPreamble(true, this->multiEngineGraph);
+            executionTarget->setPatchingPreamble(this->usePatchingPreamble, this->multiEngineGraph);
             auto res = executionTarget->appendCommandLists(1, &hCmdList, currSignalEvent, numWaitEvents, phWaitEvents);
             executionTarget->setPatchingPreamble(false, false);
             if (ZE_RESULT_SUCCESS != res) {
@@ -490,7 +558,7 @@ ze_result_t ExecutableGraph::execute(L0::CommandList *executionTarget, void *pNe
             if (L0::CommandList **cmdList = std::get_if<L0::CommandList *>(&this->submissionChain[submissioNodeId])) {
                 auto currSignalEvent = (myLastCommandList == *cmdList) ? hSignalEvent : nullptr;
                 ze_command_list_handle_t hCmdList = *cmdList;
-                executionTarget->setPatchingPreamble(true, false);
+                executionTarget->setPatchingPreamble(this->usePatchingPreamble, this->multiEngineGraph);
                 auto res = executionTarget->appendCommandLists(1, &hCmdList, currSignalEvent, 0, nullptr);
                 executionTarget->setPatchingPreamble(false, false);
                 if (ZE_RESULT_SUCCESS != res) {
@@ -542,4 +610,4 @@ void recordHandleSignalEventFromPreviousCommand(L0::CommandList &srcCmdList, Gra
     captureTarget.registerSignallingEventFromPreviousCommand(*L0::Event::fromHandle(event));
 }
 
-} // namespace L0
\ No newline at end of file
+} // namespace L0
