@@ -31,7 +31,7 @@ ze_result_t GraphDotExporter::exportToFile(const Graph &graph, const char *fileP
 
     FILE *file = NEO::IoFunctions::fopenPtr(filePath, "w");
     if (nullptr == file) {
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Failed to open file %s for writing graph content\n", filePath);
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Failed to open file %s for writing graph content\n", filePath);
         return ZE_RESULT_ERROR_UNKNOWN;
     }
 
@@ -40,7 +40,7 @@ ze_result_t GraphDotExporter::exportToFile(const Graph &graph, const char *fileP
     NEO::IoFunctions::fclosePtr(file);
 
     if (bytesWritten != dotContent.size()) {
-        PRINT_DEBUG_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Failed to write graph content to file %s\n", filePath);
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Failed to write graph content to file %s\n", filePath);
         return ZE_RESULT_ERROR_UNKNOWN;
     }
 
@@ -455,13 +455,29 @@ void addLaunchKernelExtensionParameters(std::vector<std::pair<std::string, std::
             params.emplace_back("cooperative.stype", stypeValue);
             params.emplace_back("cooperative.isCooperative", (cooperativeDesc->isCooperative != 0) ? "true" : "false");
         } else {
-            params.emplace_back("extension.stype", stypeValue + " (not recognized)");
+            addLaunchKernelAdditionalExtensionParameters(params, baseDesc);
         }
 
         baseDesc = reinterpret_cast<const ze_base_desc_t *>(baseDesc->pNext);
     }
 }
 
+void addMemoryTransferExtensionParameters(std::vector<std::pair<std::string, std::string>> &params, const void *pNext) {
+    if (pNext == nullptr) {
+        params.emplace_back("pNext", "nullptr");
+        return;
+    }
+
+    params.emplace_back("pNext", formatPointer(pNext));
+
+    const auto *baseDesc = reinterpret_cast<const ze_base_desc_t *>(pNext);
+    while (baseDesc != nullptr) {
+        addMemoryTransferAdditionalExtensionParameters(params, baseDesc);
+
+        baseDesc = reinterpret_cast<const ze_base_desc_t *>(baseDesc->pNext);
+    }
+}
+
 template <>
 std::vector<std::pair<std::string, std::string>> extractParameters<CaptureApi::zeCommandListAppendMemoryCopy>(
     const Closure<CaptureApi::zeCommandListAppendMemoryCopy> &closure, const ClosureExternalStorage &storage) {
@@ -841,6 +857,53 @@ std::vector<std::pair<std::string, std::string>> extractParameters<CaptureApi::z
     return params;
 }
 
+template <>
+std::vector<std::pair<std::string, std::string>> extractParameters<CaptureApi::zexCommandListAppendMemoryCopyWithParameters>(
+    const Closure<CaptureApi::zexCommandListAppendMemoryCopyWithParameters> &closure, const ClosureExternalStorage &storage) {
+
+    auto params = createBaseParams(closure.apiArgs);
+    params.emplace_back("dstptr", formatPointer(closure.apiArgs.dstptr));
+    params.emplace_back("srcptr", formatPointer(closure.apiArgs.srcptr));
+    params.emplace_back("size", std::to_string(closure.apiArgs.size));
+
+    addMemoryTransferExtensionParameters(params, closure.indirectArgs.pNext);
+
+    addCommonEventParameters(params, closure, storage);
+
+    return params;
+}
+
+template <>
+std::vector<std::pair<std::string, std::string>> extractParameters<CaptureApi::zexCommandListAppendMemoryFillWithParameters>(
+    const Closure<CaptureApi::zexCommandListAppendMemoryFillWithParameters> &closure, const ClosureExternalStorage &storage) {
+
+    auto params = createBaseParams(closure.apiArgs);
+    params.emplace_back("ptr", formatPointer(closure.apiArgs.ptr));
+    params.emplace_back("pattern", formatPointer(closure.indirectArgs.pattern.data()));
+    params.emplace_back("patternSize", std::to_string(closure.indirectArgs.pattern.size()));
+    params.emplace_back("size", std::to_string(closure.apiArgs.size));
+
+    addMemoryTransferExtensionParameters(params, closure.indirectArgs.pNext);
+
+    addCommonEventParameters(params, closure, storage);
+
+    return params;
+}
+
+template <>
+std::vector<std::pair<std::string, std::string>> extractParameters<CaptureApi::zeCommandListAppendHostFunction>(
+    const Closure<CaptureApi::zeCommandListAppendHostFunction> &closure, const ClosureExternalStorage &storage) {
+
+    auto params = createBaseParams(closure.apiArgs);
+    params.emplace_back("pHostFunction", formatPointer(closure.apiArgs.pHostFunction));
+    params.emplace_back("pUserData", formatPointer(closure.apiArgs.pUserData));
+    params.emplace_back("pNext", formatPointer(closure.apiArgs.pNext));
+
+    addCommonEventParameters(params, closure, storage);
+
+    return params;
+}
+
 } // namespace GraphDumpHelper
 
 } // namespace L0
