@@ -14,10 +14,17 @@ namespace Sysman {
 
 FanHandleContext::~FanHandleContext() = default;
 
+void FanHandleContext::createHandle(uint32_t fanIndex, bool multipleFansSupported) {
+    std::unique_ptr<Fan> pFan = std::make_unique<FanImp>(pOsSysman, fanIndex, multipleFansSupported);
+    handleList.push_back(std::move(pFan));
+}
+
 void FanHandleContext::init() {
-    std::unique_ptr<Fan> pFan = std::make_unique<FanImp>(pOsSysman);
-    if (pFan->initSuccess == true) {
-        handleList.push_back(std::move(pFan));
+    auto supportedFanCount = OsFan::getSupportedFanCount(pOsSysman);
+    bool multipleFansSupported = (supportedFanCount > 1);
+
+    for (uint32_t fanIndex = 0; fanIndex < supportedFanCount; fanIndex++) {
+        createHandle(fanIndex, multipleFansSupported);
     }
 }
 
@@ -26,13 +33,12 @@ ze_result_t FanHandleContext::fanGet(uint32_t *pCount, zes_fan_handle_t *phFan)
         this->init();
     });
     uint32_t handleListSize = static_cast<uint32_t>(handleList.size());
-    if (0 == *pCount) {
+    uint32_t numToCopy = std::min(*pCount, handleListSize);
+    if (0 == *pCount || *pCount > handleListSize) {
         *pCount = handleListSize;
-        return ZE_RESULT_SUCCESS;
     }
-    *pCount = std::min(*pCount, handleListSize);
     if (nullptr != phFan) {
-        for (uint32_t i = 0; i < *pCount; i++) {
+        for (uint32_t i = 0; i < numToCopy; i++) {
             phFan[i] = handleList[i]->toHandle();
         }
     }
