@@ -26,11 +26,10 @@ class FanImp : public Fan, NEO::NonCopyableAndNonMovableClass {
     ze_result_t fanSetSpeedTableMode(const zes_fan_speed_table_t *pSpeedTable) override;
     ze_result_t fanGetState(zes_fan_speed_units_t units, int32_t *pSpeed) override;
     FanImp() = default;
-    FanImp(OsSysman *pOsSysman);
+    FanImp(OsSysman *pOsSysman, uint32_t fanIndex, bool multipleFansSupported);
     ~FanImp() override;
 
     std::unique_ptr<OsFan> pOsFan;
-    void init();
 };
 } // namespace Sysman
 } // namespace L0
