@@ -50,7 +50,7 @@ ze_result_t LinuxPowerImp::getDefaultLimit(int32_t &defaultLimit) {
     uint64_t powerLimit = 0;
     auto result = pSysfsAccess->read(defaultPowerLimitFile, powerLimit);
     if (result != ZE_RESULT_SUCCESS) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), defaultPowerLimitFile.c_str(), getErrorCode(result));
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), defaultPowerLimitFile.c_str(), getErrorCode(result));
         return getErrorCode(result);
     }
 
@@ -87,7 +87,7 @@ ze_result_t LinuxPowerImp::getEnergyCounter(zes_power_energy_counter_t *pEnergy)
     }
 
     if ((result = pSysfsAccess->read(energyCounterNodeFile, pEnergy->energy)) != ZE_RESULT_SUCCESS) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), energyCounterNodeFile.c_str(), getErrorCode(result));
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), energyCounterNodeFile.c_str(), getErrorCode(result));
         return result;
     }
 
@@ -107,7 +107,7 @@ ze_result_t LinuxPowerImp::getLimits(zes_power_sustained_limit_t *pSustained, ze
         val = 0;
         result = pSysfsAccess->read(sustainedPowerLimitFile, val);
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
             return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
         }
         pSysmanKmdInterface->convertSysfsValueUnit(SysfsValueUnit::milli, pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageSustainedPowerLimit), val, val);
@@ -124,7 +124,7 @@ ze_result_t LinuxPowerImp::getLimits(zes_power_sustained_limit_t *pSustained, ze
     if (pPeak != nullptr) {
         result = pSysfsAccess->read(criticalPowerLimitFile, val);
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
             return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
         }
         pSysmanKmdInterface->convertSysfsValueUnit(SysfsValueUnit::milli, pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageCriticalPowerLimit), val, val);
@@ -149,7 +149,7 @@ ze_result_t LinuxPowerImp::setLimits(const zes_power_sustained_limit_t *pSustain
         pSysmanKmdInterface->convertSysfsValueUnit(pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageSustainedPowerLimit), SysfsValueUnit::milli, val, val);
         result = pSysfsAccess->write(sustainedPowerLimitFile, val);
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
             return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
         }
     }
@@ -159,7 +159,7 @@ ze_result_t LinuxPowerImp::setLimits(const zes_power_sustained_limit_t *pSustain
         pSysmanKmdInterface->convertSysfsValueUnit(pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageCriticalPowerLimit), SysfsValueUnit::milli, val, val);
         result = pSysfsAccess->write(criticalPowerLimitFile, val);
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
             return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
         }
     }
@@ -168,26 +168,32 @@ ze_result_t LinuxPowerImp::setLimits(const zes_power_sustained_limit_t *pSustain
 }
 
 ze_result_t LinuxPowerImp::getEnergyThreshold(zes_energy_threshold_t *pThreshold) {
-    NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s() returning UNSUPPORTED_FEATURE \n", __FUNCTION__);
+    PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s() returning UNSUPPORTED_FEATURE \n", __FUNCTION__);
     return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
 }
 
 ze_result_t LinuxPowerImp::setEnergyThreshold(double threshold) {
-    NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s() returning UNSUPPORTED_FEATURE \n", __FUNCTION__);
+    PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s() returning UNSUPPORTED_FEATURE \n", __FUNCTION__);
     return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
 }
 
 ze_result_t LinuxPowerImp::getLimitsExt(uint32_t *pCount, zes_power_limit_ext_desc_t *pLimitExt) {
-    ze_result_t result = ZE_RESULT_SUCCESS;
+    ze_result_t result = ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
 
-    if ((*pCount == 0) || (powerLimitCount < *pCount)) {
-        *pCount = powerLimitCount;
-    }
-
-    if (isSubdevice || pLimitExt == nullptr) {
+    if (isSubdevice) {
+        *pCount = 0;
         return result;
     }
 
+    result = ZE_RESULT_SUCCESS;
+
+    if (*pCount == 0) {
+        *pCount = powerLimitCount;
+        return result;
+    }
+
+    uint32_t numOfLimitsToReturn = std::min(*pCount, powerLimitCount);
+
     bool sustainedLimitReadSuccess = true;
     bool sustainedLimitIntervalReadSuccess = true;
     bool burstLimitReadSuccess = true;
@@ -195,19 +201,19 @@ ze_result_t LinuxPowerImp::getLimitsExt(uint32_t *pCount, zes_power_limit_ext_de
 
     uint64_t powerLimit = 0;
     int32_t interval = 0;
-    uint8_t count = 0;
+    uint32_t limitIndex = 0;
 
     if (sustainedPowerLimitFileExists) {
         result = pSysfsAccess->read(sustainedPowerLimitFile, powerLimit);
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
             sustainedLimitReadSuccess = false;
         }
 
         if (sustainedLimitReadSuccess) {
             result = pSysfsAccess->read(sustainedPowerLimitIntervalFile, interval);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitIntervalFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitIntervalFile.c_str(), getErrorCode(result));
                 sustainedLimitIntervalReadSuccess = false;
             }
         }
@@ -217,22 +223,22 @@ ze_result_t LinuxPowerImp::getLimitsExt(uint32_t *pCount, zes_power_limit_ext_de
         }
 
         pSysmanKmdInterface->convertSysfsValueUnit(SysfsValueUnit::milli, pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageSustainedPowerLimit), powerLimit, powerLimit);
-        pLimitExt[count].limit = static_cast<int32_t>(powerLimit);
-        pLimitExt[count].enabledStateLocked = true;
-        pLimitExt[count].intervalValueLocked = false;
-        pLimitExt[count].limitValueLocked = false;
-        pLimitExt[count].source = ZES_POWER_SOURCE_ANY;
-        pLimitExt[count].level = ZES_POWER_LEVEL_SUSTAINED;
-        pLimitExt[count].limitUnit = ZES_LIMIT_UNIT_POWER;
-        pLimitExt[count].interval = sustainedLimitIntervalReadSuccess ? interval : -1;
-        count++;
+        pLimitExt[limitIndex].limit = static_cast<int32_t>(powerLimit);
+        pLimitExt[limitIndex].enabledStateLocked = true;
+        pLimitExt[limitIndex].intervalValueLocked = false;
+        pLimitExt[limitIndex].limitValueLocked = false;
+        pLimitExt[limitIndex].source = ZES_POWER_SOURCE_ANY;
+        pLimitExt[limitIndex].level = ZES_POWER_LEVEL_SUSTAINED;
+        pLimitExt[limitIndex].limitUnit = ZES_LIMIT_UNIT_POWER;
+        pLimitExt[limitIndex].interval = sustainedLimitIntervalReadSuccess ? interval : -1;
+        limitIndex++;
     }
 
-    if (burstPowerLimitFileExists) {
+    if (burstPowerLimitFileExists && (limitIndex < numOfLimitsToReturn)) {
         powerLimit = 0;
         result = pSysfsAccess->read(burstPowerLimitFile, powerLimit);
         if (result != ZE_RESULT_SUCCESS) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitFile.c_str(), getErrorCode(result));
             burstLimitReadSuccess = false;
         }
 
@@ -240,7 +246,7 @@ ze_result_t LinuxPowerImp::getLimitsExt(uint32_t *pCount, zes_power_limit_ext_de
             interval = 0;
             result = pSysfsAccess->read(burstPowerLimitIntervalFile, interval);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitIntervalFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitIntervalFile.c_str(), getErrorCode(result));
                 burstLimitIntervalReadSuccess = false;
             }
         }
@@ -250,35 +256,37 @@ ze_result_t LinuxPowerImp::getLimitsExt(uint32_t *pCount, zes_power_limit_ext_de
         }
 
         pSysmanKmdInterface->convertSysfsValueUnit(SysfsValueUnit::milli, pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageSustainedPowerLimit), powerLimit, powerLimit);
-        pLimitExt[count].limit = static_cast<int32_t>(powerLimit);
-        pLimitExt[count].enabledStateLocked = true;
-        pLimitExt[count].intervalValueLocked = false;
-        pLimitExt[count].limitValueLocked = false;
-        pLimitExt[count].source = ZES_POWER_SOURCE_ANY;
-        pLimitExt[count].level = ZES_POWER_LEVEL_BURST;
-        pLimitExt[count].limitUnit = ZES_LIMIT_UNIT_POWER;
-        pLimitExt[count].interval = burstLimitIntervalReadSuccess ? interval : -1;
-        count++;
+        pLimitExt[limitIndex].limit = static_cast<int32_t>(powerLimit);
+        pLimitExt[limitIndex].enabledStateLocked = true;
+        pLimitExt[limitIndex].intervalValueLocked = false;
+        pLimitExt[limitIndex].limitValueLocked = false;
+        pLimitExt[limitIndex].source = ZES_POWER_SOURCE_ANY;
+        pLimitExt[limitIndex].level = ZES_POWER_LEVEL_BURST;
+        pLimitExt[limitIndex].limitUnit = ZES_LIMIT_UNIT_POWER;
+        pLimitExt[limitIndex].interval = burstLimitIntervalReadSuccess ? interval : -1;
+        limitIndex++;
     }
 
-    if (criticalPowerLimitFileExists) {
+    if (criticalPowerLimitFileExists && (limitIndex < numOfLimitsToReturn)) {
         powerLimit = 0;
         result = pSysfsAccess->read(criticalPowerLimitFile, powerLimit);
         if (result != ZE_RESULT_SUCCESS) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->read() failed to read %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
             return getErrorCode(result);
         }
 
-        pLimitExt[count].enabledStateLocked = true;
-        pLimitExt[count].intervalValueLocked = true;
-        pLimitExt[count].limitValueLocked = false;
-        pLimitExt[count].source = ZES_POWER_SOURCE_ANY;
-        pLimitExt[count].level = ZES_POWER_LEVEL_PEAK;
-        pLimitExt[count].interval = 0;
-        pLimitExt[count].limit = pSysmanProductHelper->getPowerLimitValue(powerLimit);
-        pLimitExt[count].limitUnit = pSysmanProductHelper->getPowerLimitUnit();
+        pLimitExt[limitIndex].enabledStateLocked = true;
+        pLimitExt[limitIndex].intervalValueLocked = true;
+        pLimitExt[limitIndex].limitValueLocked = false;
+        pLimitExt[limitIndex].source = ZES_POWER_SOURCE_ANY;
+        pLimitExt[limitIndex].level = ZES_POWER_LEVEL_PEAK;
+        pLimitExt[limitIndex].interval = 0;
+        pLimitExt[limitIndex].limit = pSysmanProductHelper->getPowerLimitValue(powerLimit);
+        pLimitExt[limitIndex].limitUnit = pSysmanProductHelper->getPowerLimitUnit();
+        limitIndex++;
     }
 
+    *pCount = limitIndex;
     return ZE_RESULT_SUCCESS;
 }
 
@@ -297,37 +305,37 @@ ze_result_t LinuxPowerImp::setLimitsExt(uint32_t *pCount, zes_power_limit_ext_de
             pSysmanKmdInterface->convertSysfsValueUnit(pSysmanKmdInterface->getNativeUnit(SysfsName::sysfsNamePackageSustainedPowerLimit), SysfsValueUnit::milli, val, val);
             result = pSysfsAccess->write(sustainedPowerLimitFile, val);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitFile.c_str(), getErrorCode(result));
                 return getErrorCode(result);
             }
 
             result = pSysfsAccess->write(sustainedPowerLimitIntervalFile, pLimitExt[i].interval);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitIntervalFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), sustainedPowerLimitIntervalFile.c_str(), getErrorCode(result));
                 return getErrorCode(result);
             }
         } else if (pLimitExt[i].level == ZES_POWER_LEVEL_BURST) {
             val = pSysmanProductHelper->setPowerLimitValue(pLimitExt[i].limit);
             result = pSysfsAccess->write(burstPowerLimitFile, val);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitFile.c_str(), getErrorCode(result));
                 return getErrorCode(result);
             }
 
             result = pSysfsAccess->write(burstPowerLimitIntervalFile, pLimitExt[i].interval);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitIntervalFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), burstPowerLimitIntervalFile.c_str(), getErrorCode(result));
                 return getErrorCode(result);
             }
         } else if (pLimitExt[i].level == ZES_POWER_LEVEL_PEAK) {
             val = pSysmanProductHelper->setPowerLimitValue(pLimitExt[i].limit);
             result = pSysfsAccess->write(criticalPowerLimitFile, val);
             if (ZE_RESULT_SUCCESS != result) {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): SysfsAccess->write() failed to write into %s/%s and returning error:0x%x \n", __FUNCTION__, intelGraphicsHwmonDir.c_str(), criticalPowerLimitFile.c_str(), getErrorCode(result));
                 return getErrorCode(result);
             }
         } else {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s() returning UNSUPPORTED_FEATURE \n", __FUNCTION__);
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s() returning UNSUPPORTED_FEATURE \n", __FUNCTION__);
             return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
         }
     }
