@@ -13,11 +13,7 @@ namespace Sysman {
 constexpr static auto gfxProduct = IGFX_LUNARLAKE;
 
 #include "level_zero/sysman/source/shared/linux/product_helper/sysman_product_helper_xe_hp_and_later.inl"
-
-template <>
-bool SysmanProductHelperHw<gfxProduct>::isZesInitSupported() {
-    return true;
-}
+#include "level_zero/sysman/source/shared/product_helper/sysman_os_agnostic_product_helper_xe2_and_later.inl"
 
 template class SysmanProductHelperHw<gfxProduct>;
 
