@@ -8,20 +8,23 @@
 #pragma once
 
 #include "shared/source/built_ins/sip.h"
-#include "shared/source/debugger/DebuggerStateSaveHeader.h"
 #include "shared/source/helpers/string.h"
 
 #include "level_zero/tools/source/debug/debug_session.h"
 #include "level_zero/zet_intel_gpu_debug.h"
 
+#include "StateSaveAreaHeaderWrapper.h"
+
 #include <atomic>
 #include <chrono>
 #include <cmath>
 #include <condition_variable>
 #include <mutex>
+#include <optional>
 #include <queue>
 
 namespace NEO {
+class ProductHelper;
 struct StateSaveAreaHeader;
 } // namespace NEO
 
@@ -52,7 +55,7 @@ struct DebugSessionImp : DebugSession {
         v2,
     };
 
-    struct SlmAddress {
+    struct SipTransferAddr {
         uint64_t sipOffset;
         uint32_t sipSize;
         uint64_t gpuMemOffset;
@@ -128,8 +131,15 @@ struct DebugSessionImp : DebugSession {
     MOCKABLE_VIRTUAL const NEO::ProductHelper &getProductHelper() const;
     MOCKABLE_VIRTUAL SlmAccessProtocol getSlmAccessProtocol() const;
     MOCKABLE_VIRTUAL bool getSlmStartOffset(uint64_t memoryHandle, EuThread::ThreadId threadId, uint32_t *slmStartOffset);
-    MOCKABLE_VIRTUAL std::optional<SlmAddress> getSlmAddresses(EuThread::ThreadId threadId, size_t size, const zet_debug_memory_space_desc_t *desc);
+    MOCKABLE_VIRTUAL bool getBarrierStartOffset(uint64_t memoryHandle, EuThread::ThreadId threadId, uint32_t *slmStartOffset);
+    MOCKABLE_VIRTUAL std::optional<SipTransferAddr> getSlmAddresses(EuThread::ThreadId threadId, size_t size, const zet_debug_memory_space_desc_t *desc);
+    MOCKABLE_VIRTUAL std::optional<SipTransferAddr> getBarrierAddresses(EuThread::ThreadId threadId, size_t size, const zet_debug_memory_space_desc_t *desc);
+
+    MOCKABLE_VIRTUAL ze_result_t readMemViaSipTransaction(NEO::SipKernel::Command commandId, EuThread::ThreadId threadId, const SipTransferAddr &addr, size_t size, void *buffer);
     MOCKABLE_VIRTUAL ze_result_t slmMemoryReadV2(EuThread::ThreadId threadId, const zet_debug_memory_space_desc_t *desc, size_t size, void *buffer);
+    MOCKABLE_VIRTUAL ze_result_t readBarrierMemory(EuThread::ThreadId threadId, const zet_debug_memory_space_desc_t *desc, size_t size, void *buffer);
+
+    MOCKABLE_VIRTUAL ze_result_t writeMemViaSipTransaction(NEO::SipKernel::Command commandId, EuThread::ThreadId threadId, const SipTransferAddr &addr, size_t size, const void *buffer);
     MOCKABLE_VIRTUAL ze_result_t slmMemoryWriteV2(EuThread::ThreadId threadId, const zet_debug_memory_space_desc_t *desc, size_t size, const void *buffer);
 
     MOCKABLE_VIRTUAL ze_result_t validateThreadAndDescForMemoryAccess(ze_device_thread_t thread, const zet_debug_memory_space_desc_t *desc);
@@ -142,6 +152,9 @@ struct DebugSessionImp : DebugSession {
     ze_result_t readSbaRegisters(EuThread::ThreadId thread, uint32_t start, uint32_t count, void *pRegisterValues);
     ze_result_t readModeFlags(uint32_t start, uint32_t count, void *pRegisterValues);
     ze_result_t readDebugScratchRegisters(uint32_t start, uint32_t count, void *pRegisterValues);
+    ze_result_t getScratchRenderSurfaceStateAddress(EuThread::ThreadId thread, uint64_t *result);
+    ze_result_t getScratchRenderSurfaceStateAddressV1(EuThread::ThreadId thread, uint64_t *result);
+    MOCKABLE_VIRTUAL ze_result_t getScratchRenderSurfaceStateAddressV2(EuThread::ThreadId thread, uint64_t *result);
     MOCKABLE_VIRTUAL ze_result_t readThreadScratchRegisters(EuThread::ThreadId thread, uint32_t start, uint32_t count, void *pRegisterValues);
 
     MOCKABLE_VIRTUAL bool isForceExceptionOrForceExternalHaltOnlyExceptionReason(uint32_t *cr0);
@@ -171,7 +184,7 @@ struct DebugSessionImp : DebugSession {
                                       uint32_t start, uint32_t count, uint32_t type, void *pRegisterValues, bool write);
 
     void slmSipVersionCheck();
-    MOCKABLE_VIRTUAL ze_result_t cmdRegisterAccessHelper(const EuThread::ThreadId &threadId, SIP::sip_command &command, bool write);
+    MOCKABLE_VIRTUAL ze_result_t cmdRegisterAccessHelper(const EuThread::ThreadId &threadId, NEO::SipCommandRegisterValues &command, bool write);
     MOCKABLE_VIRTUAL ze_result_t waitForCmdReady(EuThread::ThreadId threadId, uint16_t retryCount);
     ze_result_t getCommandRegisterDescriptor(const NEO::StateSaveAreaHeader *stateSaveAreaHeader, SIP::regset_desc *regdesc);
 
@@ -179,6 +192,7 @@ struct DebugSessionImp : DebugSession {
 
     size_t calculateThreadSlotOffset(EuThread::ThreadId threadId);
     size_t calculateRegisterOffsetInThreadSlot(const SIP::regset_desc *const regdesc, uint32_t start);
+    size_t getSipCommandRegisterValues(NEO::SipCommandRegisterValues &command, bool write, size_t size);
 
     bool openSipWrapper(NEO::Device *neoDevice, uint64_t contextHandle, uint64_t gpuVa) override;
     bool closeSipWrapper(NEO::Device *neoDevice, uint64_t contextHandle) override;
@@ -268,7 +282,7 @@ ze_result_t DebugSessionImp::slmMemoryAccess(EuThread::ThreadId threadId, const
         return ZE_RESULT_ERROR_UNSUPPORTED_VERSION;
     }
 
-    SIP::sip_command sipCommand = {0};
+    NEO::SipCommandRegisterValues sipCommand = {{0}};
 
     uint64_t offset = desc->address & maxNBitValue(slmAddressSpaceTag);
     // SIP accesses SLM in units of slmSendBytesSize at offset alignment of slmSendBytesSize
@@ -306,7 +320,7 @@ ze_result_t DebugSessionImp::slmMemoryAccess(EuThread::ThreadId threadId, const
     uint32_t loops = static_cast<uint32_t>(std::ceil(static_cast<float>(remainingSlmSendUnits) / maxUnitsPerLoop));
     uint32_t accessUnits = 0;
     uint32_t countReadyBytes = 0;
-    sipCommand.offset = alignedOffset;
+    sipCommand.sip_commandValues.offset = alignedOffset;
 
     for (uint32_t loop = 0; loop < loops; loop++) {
 
@@ -317,12 +331,12 @@ ze_result_t DebugSessionImp::slmMemoryAccess(EuThread::ThreadId threadId, const
         }
 
         if constexpr (write) {
-            sipCommand.command = static_cast<uint32_t>(NEO::SipKernel::Command::slmWrite);
-            sipCommand.size = static_cast<uint32_t>(accessUnits);
-            memcpy_s(sipCommand.buffer, accessUnits * slmSendBytesSize, tmpBuffer.get() + countReadyBytes, accessUnits * slmSendBytesSize);
+            sipCommand.sip_commandValues.command = static_cast<uint32_t>(NEO::SipKernel::Command::slmWrite);
+            sipCommand.sip_commandValues.size = static_cast<uint32_t>(accessUnits);
+            memcpy_s(sipCommand.sip_commandValues.buffer, accessUnits * slmSendBytesSize, tmpBuffer.get() + countReadyBytes, accessUnits * slmSendBytesSize);
         } else {
-            sipCommand.command = static_cast<uint32_t>(NEO::SipKernel::Command::slmRead);
-            sipCommand.size = static_cast<uint32_t>(accessUnits);
+            sipCommand.sip_commandValues.command = static_cast<uint32_t>(NEO::SipKernel::Command::slmRead);
+            sipCommand.sip_commandValues.size = static_cast<uint32_t>(accessUnits);
         }
 
         status = cmdRegisterAccessHelper(threadId, sipCommand, true);
@@ -346,13 +360,13 @@ ze_result_t DebugSessionImp::slmMemoryAccess(EuThread::ThreadId threadId, const
                 return status;
             }
 
-            memcpy_s(tmpBuffer.get() + countReadyBytes, accessUnits * slmSendBytesSize, sipCommand.buffer, accessUnits * slmSendBytesSize);
+            memcpy_s(tmpBuffer.get() + countReadyBytes, accessUnits * slmSendBytesSize, sipCommand.sip_commandValues.buffer, accessUnits * slmSendBytesSize);
         }
 
         remainingSlmSendUnits -= accessUnits;
         countReadyBytes += accessUnits * slmSendBytesSize;
         alignedOffset += accessUnits * slmSendBytesSize;
-        sipCommand.offset = alignedOffset;
+        sipCommand.sip_commandValues.offset = alignedOffset;
     }
 
     if constexpr (!write) {
