@@ -93,8 +93,12 @@ ze_result_t DebugSessionLinux::translateDebuggerOpenErrno(int error) {
         result = ZE_RESULT_ERROR_NOT_AVAILABLE;
         break;
     case EACCES:
+    case EPERM:
         result = ZE_RESULT_ERROR_INSUFFICIENT_PERMISSIONS;
         break;
+    case ENOMEM:
+        result = ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
+        break;
     }
     return result;
 }
@@ -189,7 +193,7 @@ bool DebugSessionLinux::checkAllEventsCollected() {
             allEventsCollected = true;
         }
     }
-    PRINT_DEBUGGER_INFO_LOG("checkAllEventsCollected() returned %d, clientHandle = %ull\n", static_cast<int>(allEventsCollected), this->clientHandle);
+    PRINT_DEBUGGER_INFO_LOG("checkAllEventsCollected() returned %d, clientHandle = %llu\n", static_cast<int>(allEventsCollected), this->clientHandle);
     return allEventsCollected;
 }
 
@@ -476,6 +480,8 @@ ze_result_t DebugSessionLinux::readMemory(ze_device_thread_t thread, const zet_d
         return readDefaultMemory(thread, desc, size, buffer);
     } else if (desc->type == ZET_DEBUG_MEMORY_SPACE_TYPE_SLM) {
         return readSlm(convertToThreadId(thread), desc, size, buffer);
+    } else if (desc->type == ZET_DEBUG_MEMORY_SPACE_TYPE_BARRIER) {
+        return readBarrierMemory(convertToThreadId(thread), desc, size, buffer);
     }
     return ZE_RESULT_ERROR_INVALID_ARGUMENT;
 }
