@@ -74,26 +74,24 @@ ze_result_t MetricSource::validateMetricsAgainstScopesAndGetExcludedMetrics(cons
     for (const auto &metric : metrics) {
         uint32_t metricSupportedScopeCount = 0;
         metric->getScopes(&metricSupportedScopeCount, nullptr);
+        DEBUG_BREAK_IF(metricSupportedScopeCount == 0);
 
-        if (metricSupportedScopeCount > 0) {
-            std::vector<zet_intel_metric_scope_exp_handle_t> metricSupportedScopes(metricSupportedScopeCount);
-            metric->getScopes(&metricSupportedScopeCount, metricSupportedScopes.data());
-            DEBUG_BREAK_IF(metricSupportedScopeCount == 0);
+        std::vector<zet_intel_metric_scope_exp_handle_t> metricSupportedScopes(metricSupportedScopeCount);
+        metric->getScopes(&metricSupportedScopeCount, metricSupportedScopes.data());
 
-            // Check if all requested scopes are supported by the metric
-            for (uint32_t i = 0; i < scopeCount; i++) {
-                bool scopeSupported = false;
-                for (const auto &supportedScope : metricSupportedScopes) {
-                    if (phMetricScopes[i] == supportedScope) {
-                        scopeSupported = true;
-                        break;
-                    }
-                }
-                if (!scopeSupported) {
-                    excludedMetrics.push_back(metric);
+        // Check if all requested scopes are supported by the metric
+        for (uint32_t i = 0; i < scopeCount; i++) {
+            bool scopeSupported = false;
+            for (const auto &supportedScope : metricSupportedScopes) {
+                if (phMetricScopes[i] == supportedScope) {
+                    scopeSupported = true;
                     break;
                 }
             }
+            if (!scopeSupported) {
+                excludedMetrics.push_back(metric);
+                break;
+            }
         }
     }
 
@@ -718,7 +716,13 @@ ze_result_t MetricDeviceContext::calcOperationCreate(zet_context_handle_t hConte
     filteredCalculationDesc.phMetricScopes = phMetricScopes.empty() ? nullptr : phMetricScopes.data();
 
     MetricSource &metricSource = (metricGroupImp) ? metricGroupImp->getMetricSource() : metricImp->getMetricSource(); // NOLINT(clang-analyzer-core.CallAndMessage)
-    return metricSource.calcOperationCreate(*this, &filteredCalculationDesc, phCalculationOperation);
+    ze_result_t status = metricSource.calcOperationCreate(*this, &filteredCalculationDesc, phCalculationOperation);
+    if (status == ZE_INTEL_RESULT_WARNING_TIME_PARAMS_IGNORED_EXP) {
+        pCalculationDesc->timeWindowsCount = filteredCalculationDesc.timeWindowsCount;
+        pCalculationDesc->timeAggregationWindow = filteredCalculationDesc.timeAggregationWindow;
+    }
+
+    return status;
 }
 
 std::unique_ptr<MetricScopeImp> MetricScopeImp::create(zet_intel_metric_scope_properties_exp_t &scopeProperties, bool aggregated, uint32_t computeSubDeviceIndex) {
@@ -1227,11 +1231,11 @@ ze_result_t metricAppendMarker(zet_command_list_handle_t hCommandList, zet_metri
 }
 
 ze_result_t getMetricSupportedScopes(
-    zet_metric_handle_t *phMetric,
+    zet_metric_handle_t hMetric,
     uint32_t *pScopesCount,
     zet_intel_metric_scope_exp_handle_t *phMetricScopes) {
 
-    auto metricImp = static_cast<MetricImp *>(Metric::fromHandle(*phMetric));
+    auto metricImp = static_cast<MetricImp *>(Metric::fromHandle(hMetric));
     return metricImp->getScopes(pScopesCount, phMetricScopes);
 }
 
