@@ -50,7 +50,7 @@ struct METRICS_LOG_BITMASK {                    // NOLINT(readability-identifier
 };
 
 #define METRICS_LOG(out, ...) \
-    NEO::printDebugString(true, out, __VA_ARGS__);
+    PRINT_STRING(true, out, __VA_ARGS__);
 
 #define METRICS_LOG_ERR(str, ...)                                                                               \
     if (NEO::debugManager.flags.PrintL0MetricLogs.get() & METRICS_LOG_BITMASK::LOG_ERROR) {                     \
@@ -262,6 +262,7 @@ struct MetricImp : public Metric {
     void setRootDevMetric(MultiDeviceMetricImp *inputRootDevMetricImp) {
         rootDeviceMetricImp = inputRootDevMetricImp;
     };
+    ze_result_t getScopes(uint32_t *pCount, zet_intel_metric_scope_exp_handle_t *phScopes);
 
   protected:
     MetricSource &metricSource;
@@ -269,9 +270,6 @@ struct MetricImp : public Metric {
     bool isMultiDevice = false;
     MultiDeviceMetricImp *rootDeviceMetricImp = nullptr;
     std::vector<MetricScopeImp *> metricScopes = {};
-
-  public:
-    ze_result_t getScopes(uint32_t *pCount, zet_intel_metric_scope_exp_handle_t *phScopes);
 };
 
 struct MultiDeviceMetricImp : public MetricImp {
@@ -653,6 +651,6 @@ ze_result_t metricScopesGet(zet_context_handle_t hContext, zet_device_handle_t h
                             zet_intel_metric_scope_exp_handle_t *phMetricScopes);
 ze_result_t metricScopeGetProperties(zet_intel_metric_scope_exp_handle_t hMetricScope, zet_intel_metric_scope_properties_exp_t *pMetricScopeProperties);
 ze_result_t metricAppendMarker(zet_command_list_handle_t hCommandList, zet_metric_group_handle_t hMetricGroup, uint32_t value);
-ze_result_t getMetricSupportedScopes(zet_metric_handle_t *phMetric, uint32_t *pScopesCount, zet_intel_metric_scope_exp_handle_t *phMetricScopes);
+ze_result_t getMetricSupportedScopes(zet_metric_handle_t hMetric, uint32_t *pScopesCount, zet_intel_metric_scope_exp_handle_t *phMetricScopes);
 
 } // namespace L0
