@@ -22,8 +22,8 @@ class OsFan {
     virtual ze_result_t setFixedSpeedMode(const zes_fan_speed_t *pSpeed) = 0;
     virtual ze_result_t setSpeedTableMode(const zes_fan_speed_table_t *pSpeedTable) = 0;
     virtual ze_result_t getState(zes_fan_speed_units_t units, int32_t *pSpeed) = 0;
-    static uint32_t getSupportedFanCount(OsSysman *pOsSysman);
-    static std::unique_ptr<OsFan> create(OsSysman *pOsSysman, uint32_t fanIndex, bool multipleFansSupported);
+    virtual bool isFanModuleSupported() = 0;
+    static std::unique_ptr<OsFan> create(OsSysman *pOsSysman);
     virtual ~OsFan() = default;
 };
 
