@@ -278,8 +278,8 @@ ze_result_t LinuxSysmanImp::gpuProcessCleanup(ze_bool_t force) {
     std::vector<int> myPidFds;
     ze_result_t result = pProcfsAccess->listProcesses(processes);
     if (ZE_RESULT_SUCCESS != result) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
-                              "gpuProcessCleanup: listProcesses() failed with error code: %ld\n", result);
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
+                     "gpuProcessCleanup: listProcesses() failed with error code: %ld\n", result);
         return result;
     }
 
@@ -296,7 +296,7 @@ ze_result_t LinuxSysmanImp::gpuProcessCleanup(ze_bool_t force) {
             if (force) {
                 pProcfsAccess->kill(pid);
             } else {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): Device in use by another process, returning error:0x%x \n", __FUNCTION__, ZE_RESULT_ERROR_HANDLE_OBJECT_IN_USE);
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): Device in use by another process, returning error:0x%x \n", __FUNCTION__, ZE_RESULT_ERROR_HANDLE_OBJECT_IN_USE);
                 return ZE_RESULT_ERROR_HANDLE_OBJECT_IN_USE;
             }
         }
@@ -429,28 +429,28 @@ ze_result_t LinuxSysmanImp::resizeVfBar(uint8_t size) {
 
     auto fdConfig = NEO::FileDescriptor(pciConfigNode.c_str(), O_RDWR);
     if (fdConfig < 0) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                              "Config node open failed\n");
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                     "Config node open failed\n");
         return ZE_RESULT_ERROR_UNKNOWN;
     }
     std::unique_ptr<uint8_t[]> configMemory = std::make_unique<uint8_t[]>(PCI_CFG_SPACE_EXP_SIZE);
     memset(configMemory.get(), 0, PCI_CFG_SPACE_EXP_SIZE);
     if (this->preadFunction(fdConfig, configMemory.get(), PCI_CFG_SPACE_EXP_SIZE, 0) < 0) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                              "Read to get config space failed\n");
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                     "Read to get config space failed\n");
         return ZE_RESULT_ERROR_UNKNOWN;
     }
     auto reBarCapPos = L0::LinuxPciImp::getRebarCapabilityPos(configMemory.get(), true);
     if (!reBarCapPos) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                              "VF BAR capability not found\n");
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                     "VF BAR capability not found\n");
         return ZE_RESULT_ERROR_UNKNOWN;
     }
 
     auto barSizePos = reBarCapPos + PCI_REBAR_CTRL + 1; // position of VF(0) BAR SIZE.
     if (this->pwriteFunction(fdConfig, &size, 0x01, barSizePos) < 0) {
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                              "Write to change VF bar size failed\n");
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                     "Write to change VF bar size failed\n");
         return ZE_RESULT_ERROR_UNKNOWN;
     }
     return ZE_RESULT_SUCCESS;
@@ -495,8 +495,8 @@ ze_result_t LinuxSysmanImp::osWarmReset() {
         if (NEO::debugManager.flags.DebugSetMemoryDiagnosticsDelay.get() != -1) {
             delayDurationForPPR = NEO::debugManager.flags.DebugSetMemoryDiagnosticsDelay.get();
         }
-        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                              "Delay of %d mins introduced to allow HBM IFR to complete\n", delayDurationForPPR);
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                     "Delay of %d mins introduced to allow HBM IFR to complete\n", delayDurationForPPR);
         NEO::sleep(std::chrono::seconds(delayDurationForPPR * 60));
     } else {
         NEO::sleep(std::chrono::seconds(10)); // Sleep for 10 seconds to make sure writing to bridge control offset is propagated.
@@ -521,16 +521,16 @@ ze_result_t LinuxSysmanImp::osWarmReset() {
 
         result = pFsAccess->write(cardBusPath + '/' + "remove", "1");
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                                  "Card Bus remove after resizing VF bar failed\n");
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                         "Card Bus remove after resizing VF bar failed\n");
             return result;
         }
         NEO::sleep(std::chrono::seconds(10)); // Sleep for 10seconds to make sure that the config spaces of all devices are saved correctly.
 
         result = pFsAccess->write(rootPortPath + '/' + "rescan", "1");
         if (ZE_RESULT_SUCCESS != result) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
-                                  "Rescanning root port failed after resizing VF bar failed\n");
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stdout,
+                         "Rescanning root port failed after resizing VF bar failed\n");
             return result;
         }
         NEO::sleep(std::chrono::seconds(10)); // Sleep for 10seconds, allows the rescan to complete on all devices attached to the root port.
