@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2020 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,4 +13,7 @@
 namespace NEO {
 
 void *CL_API_CALL getAdditionalExtensionFunctionAddress(const char *funcName);
-}
+
+bool doNotReportClPlatform();
+
+} // namespace NEO
