@@ -61,7 +61,7 @@
 namespace NEO {
 
 // Global table of create functions
-CommandQueueCreateFunc commandQueueFactory[IGFX_MAX_CORE] = {};
+CommandQueueCreateFunc commandQueueFactory[NEO::maxCoreEnumValue] = {};
 
 CommandQueue *CommandQueue::create(Context *context,
                                    ClDevice *device,
@@ -1218,9 +1218,7 @@ bool CommandQueue::isBlockedCommandStreamRequired(uint32_t commandType, const Ev
 
 bool CommandQueue::isDependenciesFlushForMarkerRequired(const EventsRequest &eventsRequest) const {
     return this->getGpgpuCommandStreamReceiver().peekTimestampPacketWriteEnabled() && !this->isOOQEnabled() &&
-           std::any_of(eventsRequest.eventWaitList, eventsRequest.eventWaitList + eventsRequest.numEventsInWaitList, [this](const auto event) {
-               return castToObjectOrAbort<Event>(event)->getCommandQueue() != this;
-           });
+           (eventsRequest.outEvent || eventsRequest.numEventsInWaitList > 0);
 }
 
 void CommandQueue::storeProperties(const cl_queue_properties *properties) {
