@@ -198,7 +198,7 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface **surfacesForResidency,
     const auto &hwInfo = this->getDevice().getHardwareInfo();
     auto &productHelper = getDevice().getProductHelper();
     bool canUsePipeControlInsteadOfSemaphoresForOnCsrDependencies = false;
-    bool isNonStallingIoqBarrier = isFlushForProfilingRequired(commandType) && !isOOQEnabled() && (debugManager.flags.OptimizeIoqBarriersHandling.get() != 0);
+    bool isNonStallingIoqBarrier = commandType == CL_COMMAND_BARRIER && !isOOQEnabled() && (debugManager.flags.OptimizeIoqBarriersHandling.get() != 0);
     const bool isNonStallingIoqBarrierWithDependencies = isNonStallingIoqBarrier && (eventsRequest.numEventsInWaitList > 0);
 
     if (computeCommandStreamReceiver.peekTimestampPacketWriteEnabled()) {
@@ -901,36 +901,36 @@ CompletionStamp CommandQueueHw<GfxFamily>::enqueueNonBlocked(
     bool hasStallingCmds = enqueueProperties.hasStallingCmds || (!relaxedOrderingEnabled && (eventsRequest.numEventsInWaitList > 0 || timestampPacketDependencies.previousEnqueueNodes.peekNodes().size() > 0));
     auto textureCacheFlush = isTextureCacheFlushNeeded(commandType) || containsImageFromBuffer;
     DispatchFlags dispatchFlags(
-        &timestampPacketDependencies.barrierNodes,                                  // barrierTimestampPacketNodes
-        {},                                                                         // pipelineSelectArgs
-        this->flushStamp->getStampReference(),                                      // flushStampReference
-        getThrottle(),                                                              // throttle
-        ClPreemptionHelper::taskPreemptionMode(getDevice(), multiDispatchInfo),     // preemptionMode
-        numGrfRequired,                                                             // numGrfRequired
-        L3CachingSettings::l3CacheOn,                                               // l3CacheSettings
-        kernel->getDescriptor().kernelAttributes.threadArbitrationPolicy,           // threadArbitrationPolicy
-        kernel->getAdditionalKernelExecInfo(),                                      // additionalKernelExecInfo
-        kernel->getExecutionType(),                                                 // kernelExecutionType
-        memoryCompressionState,                                                     // memoryCompressionState
-        getSliceCount(),                                                            // sliceCount
-        blocking,                                                                   // blocking
-        dcFlush,                                                                    // dcFlush
-        multiDispatchInfo.usesSlm(),                                                // useSLM
-        !csr.isUpdateTagFromWaitEnabled() || commandType == CL_COMMAND_FILL_BUFFER, // guardCommandBufferWithPipeControl
-        commandType == CL_COMMAND_NDRANGE_KERNEL,                                   // GSBA32BitRequired
-        (QueuePriority::low == priority),                                           // lowPriority
-        implicitFlush,                                                              // implicitFlush
-        !eventBuilder.getEvent() || csr.isNTo1SubmissionModelEnabled(),             // outOfOrderExecutionAllowed
-        false,                                                                      // epilogueRequired
-        false,                                                                      // usePerDssBackedBuffer
-        kernel->areMultipleSubDevicesInContext(),                                   // areMultipleSubDevicesInContext
-        kernel->requiresMemoryMigration(),                                          // memoryMigrationRequired
-        textureCacheFlush,                                                          // textureCacheFlush
-        hasStallingCmds,                                                            // hasStallingCmds
-        relaxedOrderingEnabled,                                                     // hasRelaxedOrderingDependencies
-        false,                                                                      // stateCacheInvalidation
-        isStallingCommandsOnNextFlushRequired(),                                    // isStallingCommandsOnNextFlushRequired
-        isDcFlushRequiredOnStallingCommandsOnNextFlush()                            // isDcFlushRequiredOnStallingCommandsOnNextFlush
+        &timestampPacketDependencies.barrierNodes,                              // barrierTimestampPacketNodes
+        {},                                                                     // pipelineSelectArgs
+        this->flushStamp->getStampReference(),                                  // flushStampReference
+        getThrottle(),                                                          // throttle
+        ClPreemptionHelper::taskPreemptionMode(getDevice(), multiDispatchInfo), // preemptionMode
+        numGrfRequired,                                                         // numGrfRequired
+        L3CachingSettings::l3CacheOn,                                           // l3CacheSettings
+        kernel->getDescriptor().kernelAttributes.threadArbitrationPolicy,       // threadArbitrationPolicy
+        kernel->getAdditionalKernelExecInfo(),                                  // additionalKernelExecInfo
+        kernel->getExecutionType(),                                             // kernelExecutionType
+        memoryCompressionState,                                                 // memoryCompressionState
+        getSliceCount(),                                                        // sliceCount
+        blocking,                                                               // blocking
+        dcFlush,                                                                // dcFlush
+        multiDispatchInfo.usesSlm(),                                            // useSLM
+        !csr.isUpdateTagFromWaitEnabled() || isFillOperation(commandType),      // guardCommandBufferWithPipeControl
+        commandType == CL_COMMAND_NDRANGE_KERNEL,                               // GSBA32BitRequired
+        (QueuePriority::low == priority),                                       // lowPriority
+        implicitFlush,                                                          // implicitFlush
+        !eventBuilder.getEvent() || csr.isNTo1SubmissionModelEnabled(),         // outOfOrderExecutionAllowed
+        false,                                                                  // epilogueRequired
+        false,                                                                  // usePerDssBackedBuffer
+        kernel->areMultipleSubDevicesInContext(),                               // areMultipleSubDevicesInContext
+        kernel->requiresMemoryMigration(),                                      // memoryMigrationRequired
+        textureCacheFlush,                                                      // textureCacheFlush
+        hasStallingCmds,                                                        // hasStallingCmds
+        relaxedOrderingEnabled,                                                 // hasRelaxedOrderingDependencies
+        false,                                                                  // stateCacheInvalidation
+        isStallingCommandsOnNextFlushRequired(),                                // isStallingCommandsOnNextFlushRequired
+        isDcFlushRequiredOnStallingCommandsOnNextFlush()                        // isDcFlushRequiredOnStallingCommandsOnNextFlush
     );
 
     dispatchFlags.isWalkerWithProfilingEnqueued = getAndClearIsWalkerWithProfilingEnqueued();
@@ -980,7 +980,7 @@ CompletionStamp CommandQueueHw<GfxFamily>::enqueueNonBlocked(
         dispatchFlags.implicitFlush = true;
     }
 
-    PRINT_DEBUG_STRING(debugManager.flags.PrintDebugMessages.get(), stdout, "preemption = %d.\n", static_cast<int>(dispatchFlags.preemptionMode));
+    PRINT_STRING(debugManager.flags.PrintDebugMessages.get(), stdout, "preemption = %d.\n", static_cast<int>(dispatchFlags.preemptionMode));
 
     CompletionStamp completionStamp = csr.flushTask(
         commandStream,
@@ -1550,17 +1550,17 @@ cl_int CommandQueueHw<GfxFamily>::enqueueBlit(const MultiDispatchInfo &multiDisp
     if (deferredMultiRootSyncNodes.get()) {
         csrDeps.copyRootDeviceSyncNodesToNewContainer(*deferredMultiRootSyncNodes);
     }
-    if (debugManager.flags.ForceCsrLockInBcsEnqueueOnlyForGpgpuSubmission.get() != 1) {
-        commandStreamReceiverOwnership.unlock();
-    }
-    queueOwnership.unlock();
 
     if (migratedMemory) {
         bcsCsr.flushBatchedSubmissions();
         bcsCsr.flushTagUpdate();
     }
 
+    if (debugManager.flags.ForceCsrLockInBcsEnqueueOnlyForGpgpuSubmission.get() != 1) {
+        commandStreamReceiverOwnership.unlock();
+    }
     bcsCommandStreamReceiverOwnership.unlock();
+    queueOwnership.unlock();
     if (blocking) {
         const auto waitStatus = waitForAllEngines(blockQueue, nullptr, false);
         if (waitStatus == WaitStatus::gpuHang) {
