@@ -56,12 +56,13 @@ Context::~Context() {
     if (multiRootDeviceTimestampPacketAllocator.get() != nullptr) {
         multiRootDeviceTimestampPacketAllocator.reset();
     }
-
-    if (smallBufferPoolAllocator.isAggregatedSmallBuffersEnabled(this)) {
-        auto &device = this->getDevice(0)->getDevice();
-        device.recordPoolsFreed(smallBufferPoolAllocator.getPoolsCount());
-        smallBufferPoolAllocator.releasePools();
-    }
+    this->forEachBufferPoolAllocator([this](BufferPoolAllocator &allocator) {
+        if (allocator.isAggregatedSmallBuffersEnabled(this)) {
+            auto &device = this->getDevice(0)->getDevice();
+            device.recordPoolsFreed(allocator.getPoolType(), allocator.getPoolsCount());
+            allocator.releasePools();
+        }
+    });
 
     usmDeviceMemAllocPool.cleanup();
 
@@ -311,8 +312,8 @@ bool Context::createImpl(const cl_context_properties *properties,
 
         setupContextType();
         initializeManagers();
-
-        smallBufferPoolAllocator.setParams(SmallBuffersParams::getPreferredBufferPoolParams(device->getProductHelper()));
+        this->bufferPoolAllocators[BufferPoolType::SmallBuffersPool].setParams(SmallBuffersParams::getDefaultParams(), BufferPoolType::SmallBuffersPool);
+        this->bufferPoolAllocators[BufferPoolType::LargeBuffersPool].setParams(SmallBuffersParams::getLargePagesParams(), BufferPoolType::LargeBuffersPool);
     }
 
     return true;
@@ -562,24 +563,24 @@ bool Context::BufferPoolAllocator::isAggregatedSmallBuffersEnabled(Context *cont
            (isSupportedForSingleDeviceContexts && context->isSingleDeviceContext());
 }
 
-Context::BufferPool::BufferPool(Context *context) : BaseType(context->memoryManager,
-                                                             nullptr,
-                                                             SmallBuffersParams::getPreferredBufferPoolParams(context->getDevice(0)->getDevice().getProductHelper())) {
-    static constexpr cl_mem_flags flags = CL_MEM_UNCOMPRESSED_HINT_INTEL;
+Context::BufferPool::BufferPool(Context *context, const SmallBuffersParams &params, bool isCpuAccessRequired) : BaseType(context->memoryManager,
+                                                                                                                         nullptr,
+                                                                                                                         params) {
+    const cl_mem_flags flags = isCpuAccessRequired ? CL_MEM_UNCOMPRESSED_HINT_INTEL : 0;
     [[maybe_unused]] cl_int errcodeRet{};
     Buffer::AdditionalBufferCreateArgs bufferCreateArgs{};
-    bufferCreateArgs.doNotProvidePerformanceHints = true;
-    bufferCreateArgs.makeAllocationLockable = true;
+    bufferCreateArgs.isAllocationForPool = true;
+    bufferCreateArgs.makeAllocationLockable = isCpuAccessRequired;
     this->mainStorage.reset(Buffer::create(context,
                                            flags,
-                                           context->getBufferPoolAllocator().getParams().aggregatedSmallBuffersPoolSize,
+                                           params.aggregatedSmallBuffersPoolSize,
                                            nullptr,
                                            bufferCreateArgs,
                                            errcodeRet));
     if (this->mainStorage) {
         this->chunkAllocator.reset(new HeapAllocator(params.startingOffset,
-                                                     context->getBufferPoolAllocator().getParams().aggregatedSmallBuffersPoolSize,
-                                                     context->getBufferPoolAllocator().getParams().chunkAlignment));
+                                                     params.aggregatedSmallBuffersPoolSize,
+                                                     params.chunkAlignment));
         context->decRefInternal();
     }
 }
@@ -609,11 +610,15 @@ Buffer *Context::BufferPool::allocate(const MemoryProperties &memoryProperties,
 }
 
 void Context::BufferPoolAllocator::initAggregatedSmallBuffers(Context *context) {
-    this->context = context;
-    auto &device = context->getDevice(0)->getDevice();
-    if (device.requestPoolCreate(1u)) {
-        this->addNewBufferPool(Context::BufferPool{this->context});
-    }
+    std::call_once(this->lazyInitFlag, [this, context]() {
+        if (this->isAggregatedSmallBuffersEnabled(context)) {
+            this->context = context;
+            auto &device = context->getDevice(0)->getDevice();
+            if (device.requestPoolCreate(this->poolType, 1u)) {
+                this->addNewBufferPool(Context::BufferPool{this->context, this->params, this->poolType == BufferPoolType::SmallBuffersPool});
+            }
+        }
+    });
 }
 
 Buffer *Context::BufferPoolAllocator::allocateBufferFromPool(const MemoryProperties &memoryProperties,
@@ -643,8 +648,8 @@ Buffer *Context::BufferPoolAllocator::allocateBufferFromPool(const MemoryPropert
     }
 
     auto &device = context->getDevice(0)->getDevice();
-    if (device.requestPoolCreate(1u)) {
-        this->addNewBufferPool(BufferPool{this->context});
+    if (device.requestPoolCreate(this->poolType, 1u)) {
+        this->addNewBufferPool(BufferPool{this->context, this->params, this->poolType == BufferPoolType::SmallBuffersPool});
         return this->allocateFromPools(memoryProperties, flags, flagsIntel, requestedSize, hostPtr, errcodeRet);
     }
     return nullptr;
@@ -686,4 +691,9 @@ std::unique_lock<std::mutex> Context::obtainOwnershipForMultiRootDeviceAllocator
     return std::unique_lock<std::mutex>(multiRootDeviceAllocatorMtx);
 }
 
+bool Context::isPoolBuffer(const MemObj *buffer) {
+    return this->getBufferPoolAllocator(BufferPoolType::SmallBuffersPool).isPoolBuffer(buffer) ||
+           this->getBufferPoolAllocator(BufferPoolType::LargeBuffersPool).isPoolBuffer(buffer);
+}
+
 } // namespace NEO
