@@ -6,15 +6,20 @@
  */
 
 #pragma once
-#include "shared/source/compiler_interface/compiler_interface.h"
 #include "shared/source/compiler_interface/linker.h"
-#include "shared/source/device_binary_format/device_binary_formats.h"
+#include "shared/source/compiler_interface/spec_const_values_map.h"
+#include "shared/source/compiler_interface/translation_error_code.h"
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/program/program_info.h"
+#include "shared/source/utilities/const_stringref.h"
 
 #include "opencl/source/cl_device/cl_device_vector.h"
 #include "opencl/source/helpers/base_object.h"
 
+#include "cif/builtins/memory/buffer/buffer.h"
+#include "cif/common/cif.h"
+#include "ocl_igc_interface/code_type.h"
+
 #include <functional>
 
 namespace NEO {
@@ -37,7 +42,9 @@ struct MetadataGeneration;
 struct KernelInfo;
 enum class DecodeError : uint8_t;
 struct ExternalFunctionInfo;
-class SharedPoolAlloction;
+class SharedPoolAllocation;
+struct DeviceInfoKernelPayloadConstants;
+class ProductHelper;
 
 template <>
 struct OpenCLObjectMapper<_cl_program> {
@@ -52,19 +59,19 @@ using CreateFromILFunc = std::function<Program *(Context *ctx,
 extern CreateFromILFunc createFromIL;
 } // namespace ProgramFunctions
 
-constexpr cl_int asClError(TranslationOutput::ErrorCode err) {
+constexpr cl_int asClError(TranslationErrorCode err) {
     switch (err) {
     default:
         return CL_OUT_OF_HOST_MEMORY;
-    case TranslationOutput::ErrorCode::success:
+    case TranslationErrorCode::success:
         return CL_SUCCESS;
-    case TranslationOutput::ErrorCode::compilerNotAvailable:
+    case TranslationErrorCode::compilerNotAvailable:
         return CL_COMPILER_NOT_AVAILABLE;
-    case TranslationOutput::ErrorCode::compilationFailure:
+    case TranslationErrorCode::compilationFailure:
         return CL_COMPILE_PROGRAM_FAILURE;
-    case TranslationOutput::ErrorCode::buildFailure:
+    case TranslationErrorCode::buildFailure:
         return CL_BUILD_PROGRAM_FAILURE;
-    case TranslationOutput::ErrorCode::linkFailure:
+    case TranslationErrorCode::linkFailure:
         return CL_LINK_PROGRAM_FAILURE;
     }
 }
@@ -196,6 +203,26 @@ class Program : public BaseObject<_cl_program> {
     NEO::GraphicsAllocation *getGlobalSurfaceGA(uint32_t rootDeviceIndex) const;
     NEO::GraphicsAllocation *getExportedFunctionsSurface(uint32_t rootDeviceIndex) const;
 
+    MOCKABLE_VIRTUAL bool isIsaPoolingEnabled(Device &neoDevice);
+    cl_int setIsaGraphicsAllocations(
+        Device &neoDevice,
+        std::vector<KernelInfo *> &kernelInfoArray,
+        DeviceInfoKernelPayloadConstants &deviceInfoConstants,
+        uint32_t rootDeviceIndex);
+
+    MOCKABLE_VIRTUAL bool transferIsaSegmentsToAllocation(
+        Device *pDevice,
+        std::vector<KernelInfo *> &kernelInfoArray,
+        const Linker::PatchableSegments *isaSegmentsForPatching,
+        uint32_t rootDeviceIndex);
+
+    std::pair<const void *, size_t> getKernelHeapPointerAndSize(
+        KernelInfo *const &kernelInfo,
+        std::vector<KernelInfo *> &kernelInfoArray,
+        const Linker::PatchableSegments *isaSegmentsForPatching);
+
+    GraphicsAllocation *getKernelsIsaParentAllocation(uint32_t rootDeviceIndex) const;
+
     void cleanCurrentKernelInfo(uint32_t rootDeviceIndex);
 
     const std::string &getOptions() const { return options; }
@@ -331,6 +358,7 @@ class Program : public BaseObject<_cl_program> {
         std::vector<KernelInfo *> kernelInfoArray;
         std::unique_ptr<NEO::SharedPoolAllocation> constantSurface;
         std::unique_ptr<NEO::SharedPoolAllocation> globalSurface;
+        std::unique_ptr<NEO::SharedPoolAllocation> sharedIsaAllocation;
         GraphicsAllocation *exportedFunctionsSurface = nullptr;
         size_t globalVarTotalSize = 0U;
         std::unique_ptr<LinkerInput> linkerInput;
