@@ -51,7 +51,7 @@
 namespace NEO {
 
 // Global table of CommandStreamReceiver factories for HW and tests
-CommandStreamReceiverCreateFunc commandStreamReceiverFactory[2 * IGFX_MAX_CORE] = {};
+CommandStreamReceiverCreateFunc commandStreamReceiverFactory[2 * NEO::maxCoreEnumValue] = {};
 
 CommandStreamReceiver::CommandStreamReceiver(ExecutionEnvironment &executionEnvironment,
                                              uint32_t rootDeviceIndex,
@@ -98,7 +98,7 @@ CommandStreamReceiver::CommandStreamReceiver(ExecutionEnvironment &executionEnvi
     auto &compilerProductHelper = rootDeviceEnvironment.getHelper<CompilerProductHelper>();
     this->heaplessModeEnabled = compilerProductHelper.isHeaplessModeEnabled(hwInfo);
     this->heaplessStateInitEnabled = compilerProductHelper.isHeaplessStateInitEnabled(heaplessModeEnabled);
-    this->hostFunctionWorkerMode = debugManager.flags.HostFunctionWorkMode.get();
+    this->hostFunctionWorkerMode = static_cast<HostFunctionWorkerMode>(debugManager.flags.HostFunctionWorkMode.get());
 }
 
 CommandStreamReceiver::~CommandStreamReceiver() {
@@ -243,16 +243,21 @@ void CommandStreamReceiver::createHostFunctionWorker() {
         return;
     }
 
-    this->hostFunctionWorker = HostFunctionFactory::createHostFunctionWorker(this->hostFunctionWorkerMode,
-                                                                             this->isAubMode(),
-                                                                             this->downloadAllocationImpl,
-                                                                             this->getHostFunctionDataAllocation(),
-                                                                             &this->getHostFunctionData());
+    bool skipHostFunctionExecution = getType() == NEO::CommandStreamReceiverType::aub ||
+                                     getType() == NEO::CommandStreamReceiverType::nullAub;
 
-    this->hostFunctionWorker->start();
+    auto *rootDeviceEnvironment = this->executionEnvironment.rootDeviceEnvironments[rootDeviceIndex].get();
+
+    HostFunctionFactory::createAndSetHostFunctionWorker(this->hostFunctionWorkerMode,
+                                                        skipHostFunctionExecution,
+                                                        this,
+                                                        rootDeviceEnvironment);
+
+    auto *streamer = &this->getHostFunctionStreamer();
+    this->hostFunctionWorker->start(streamer);
 }
 
-IHostFunctionWorker *CommandStreamReceiver::getHostFunctionWorker() {
+HostFunctionWorker *CommandStreamReceiver::getHostFunctionWorker() {
     return this->hostFunctionWorker;
 }
 
@@ -301,7 +306,7 @@ void CommandStreamReceiver::preallocateCommandBuffer() {
 }
 
 void CommandStreamReceiver::preallocateInternalHeap() {
-    preallocateAllocation(AllocationType::internalHeap, MemoryConstants::pageSize64k);
+    preallocateAllocation(AllocationType::internalHeap, HeapSize::getDefaultHeapSize(IndirectHeapType::indirectObject));
 }
 
 void CommandStreamReceiver::fillReusableAllocationsList() {
@@ -359,6 +364,7 @@ bool CommandStreamReceiver::initializeResources(bool allocateInterrupt, const Pr
                 this->createPreemptionAllocation();
             }
             this->fillReusableAllocationsList();
+            initializeEngine();
             this->resourcesInitialized = true;
         }
     }
@@ -437,8 +443,6 @@ void CommandStreamReceiver::cleanupResources() {
         DEBUG_BREAK_IF(tagAllocation != nullptr);
         DEBUG_BREAK_IF(tagAddress != nullptr);
 
-        hostFunctionDataAllocation = nullptr;
-
         for (auto graphicsAllocation : tagsMultiAllocation->getGraphicsAllocations()) {
             getMemoryManager()->freeGraphicsMemory(graphicsAllocation);
         }
@@ -482,9 +486,16 @@ void CommandStreamReceiver::cleanupResources() {
 }
 
 void CommandStreamReceiver ::cleanupHostFunctionWorker() {
-    hostFunctionWorker->finish();
-    delete hostFunctionWorker;
-    hostFunctionWorker = nullptr;
+
+    if (hostFunctionWorker) {
+        hostFunctionWorker->finish();
+
+        if (hostFunctionWorkerMode != HostFunctionWorkerMode::schedulerWithThreadPool) {
+            delete hostFunctionWorker;
+        }
+
+        hostFunctionWorker = nullptr;
+    }
 }
 
 WaitStatus CommandStreamReceiver::waitForCompletionWithTimeout(const WaitParams &params, TaskCountType taskCountToWait) {
@@ -720,8 +731,8 @@ void *CommandStreamReceiver::getIndirectHeapCurrentPtr(IndirectHeapType heapType
     return nullptr;
 }
 
-void CommandStreamReceiver::signalHostFunctionWorker() {
-    hostFunctionWorker->submit();
+void CommandStreamReceiver::signalHostFunctionWorker(uint32_t nHostFunctions) {
+    hostFunctionWorker->submit(nHostFunctions);
 }
 
 void CommandStreamReceiver::ensureHostFunctionWorkerStarted() {
@@ -736,33 +747,29 @@ void CommandStreamReceiver::startHostFunctionWorker() {
         return;
     }
 
+    createHostFunctionStreamer();
     createHostFunctionWorker();
 
     this->hostFunctionWorkerStarted.store(true, std::memory_order_release);
 }
 
-void CommandStreamReceiver::initializeHostFunctionData() {
+void CommandStreamReceiver::createHostFunctionStreamer() {
 
+    auto nPartitions = this->activePartitions;
+    auto partitionOffset = this->immWritePostSyncWriteOffset;
     auto tagAddress = this->tagAllocation->getUnderlyingBuffer();
+    auto hostFunctionIdAddress = ptrOffset(tagAddress, static_cast<size_t>(TagAllocationLayout::hostFunctionDataOffset));
 
-    auto entryAddress = ptrOffset(tagAddress, HostFunctionHelper::entryOffset + TagAllocationLayout::hostFunctionDataOffset);
-    auto userDataAddress = ptrOffset(tagAddress, HostFunctionHelper::userDataOffset + TagAllocationLayout::hostFunctionDataOffset);
-    auto internalTagAddress = ptrOffset(tagAddress, HostFunctionHelper::internalTagOffset + TagAllocationLayout::hostFunctionDataOffset);
-
-    this->hostFunctionData.entry = reinterpret_cast<uint64_t *>(entryAddress);
-    this->hostFunctionData.userData = reinterpret_cast<uint64_t *>(userDataAddress);
-    this->hostFunctionData.internalTag = reinterpret_cast<uint32_t *>(internalTagAddress);
-    *this->hostFunctionData.entry = 0;
-    *this->hostFunctionData.userData = 0;
-    *this->hostFunctionData.internalTag = 0;
+    this->hostFunctionStreamer = std::make_unique<HostFunctionStreamer>(this->tagAllocation,
+                                                                        hostFunctionIdAddress,
+                                                                        this->downloadAllocationImpl,
+                                                                        nPartitions,
+                                                                        partitionOffset,
+                                                                        isTbxMode());
 }
 
-HostFunctionData &CommandStreamReceiver::getHostFunctionData() {
-    return hostFunctionData;
-}
-
-GraphicsAllocation *CommandStreamReceiver::getHostFunctionDataAllocation() {
-    return tagAllocation;
+HostFunctionStreamer &CommandStreamReceiver::getHostFunctionStreamer() {
+    return *hostFunctionStreamer.get();
 }
 
 IndirectHeap &CommandStreamReceiver::getIndirectHeap(IndirectHeap::Type heapType,
@@ -791,7 +798,7 @@ IndirectHeap &CommandStreamReceiver::getIndirectHeap(IndirectHeap::Type heapType
 void CommandStreamReceiver::allocateHeapMemory(IndirectHeap::Type heapType,
                                                size_t minRequiredSize, IndirectHeap *&indirectHeap) {
     size_t reservedSize = 0;
-    auto finalHeapSize = HeapSize::getDefaultHeapSize(HeapSize::defaultHeapSize);
+    auto finalHeapSize = HeapSize::getHeapSize(HeapSize::getDefaultHeapSize(heapType));
     if (IndirectHeap::Type::surfaceState == heapType) {
         finalHeapSize = defaultSshSize;
     }
@@ -910,6 +917,7 @@ bool CommandStreamReceiver::initializeTagAllocation() {
     auto tagAddress = this->tagAddress;
     auto ucTagAddress = this->ucTagAddress;
     auto completionFence = reinterpret_cast<TaskCountType *>(getCompletionAddress());
+    auto hostFunctionDataAddress = reinterpret_cast<uint64_t *>(ptrOffset(this->tagAllocation->getUnderlyingBuffer(), TagAllocationLayout::hostFunctionDataOffset));
     UNRECOVERABLE_IF(!completionFence);
     uint32_t subDevices = static_cast<uint32_t>(this->deviceBitfield.count());
     for (uint32_t i = 0; i < subDevices; i++) {
@@ -919,12 +927,14 @@ bool CommandStreamReceiver::initializeTagAllocation() {
         ucTagAddress = ptrOffset(ucTagAddress, this->immWritePostSyncWriteOffset);
         *completionFence = 0;
         completionFence = ptrOffset(completionFence, this->immWritePostSyncWriteOffset);
+        *hostFunctionDataAddress = 0u;
+        hostFunctionDataAddress = ptrOffset(hostFunctionDataAddress, this->immWritePostSyncWriteOffset);
     }
     *this->debugPauseStateAddress = debugManager.flags.EnableNullHardware.get() ? DebugPauseState::disabled : DebugPauseState::waitingForFirstSemaphore;
 
-    PRINT_DEBUG_STRING(debugManager.flags.PrintTagAllocationAddress.get(), stdout,
-                       "\nCreated tag allocation %p for engine %u\n",
-                       this->tagAddress, static_cast<uint32_t>(osContext->getEngineType()));
+    PRINT_STRING(debugManager.flags.PrintTagAllocationAddress.get(), stdout,
+                 "\nCreated tag allocation %p for engine %u\n",
+                 this->tagAddress, static_cast<uint32_t>(osContext->getEngineType()));
 
     if (debugManager.flags.PauseOnEnqueue.get() != -1 || debugManager.flags.PauseOnBlitCopy.get() != -1) {
         userPauseConfirmation = Thread::createFunc(CommandStreamReceiver::asyncDebugBreakConfirmation, reinterpret_cast<void *>(this));
@@ -932,8 +942,6 @@ bool CommandStreamReceiver::initializeTagAllocation() {
 
     this->barrierCountTagAddress = ptrOffset(this->tagAddress, TagAllocationLayout::barrierCountOffset);
 
-    initializeHostFunctionData();
-
     return true;
 }
 
@@ -1096,24 +1104,22 @@ bool CommandStreamReceiver::needsPageTableManager() const {
 }
 
 void CommandStreamReceiver::printDeviceIndex() {
-    if (debugManager.flags.PrintDeviceAndEngineIdOnSubmission.get()) {
-        printf("%u: Submission to RootDevice Index: %u, Sub-Devices Mask: %lu, EngineId: %u (%s, %s)\n",
-               SysCalls::getProcessId(),
-               this->getRootDeviceIndex(),
-               this->osContext->getDeviceBitfield().to_ulong(),
-               this->osContext->getEngineType(),
-               EngineHelpers::engineTypeToString(this->osContext->getEngineType()).c_str(),
-               EngineHelpers::engineUsageToString(this->osContext->getEngineUsage()).c_str());
-    }
+    PRINT_STRING(debugManager.flags.PrintDeviceAndEngineIdOnSubmission.get(), stdout,
+                 "%u: Submission to RootDevice Index: %u, Sub-Devices Mask: %lu, EngineId: %u (%s, %s)\n",
+                 SysCalls::getProcessId(),
+                 this->getRootDeviceIndex(),
+                 this->osContext->getDeviceBitfield().to_ulong(),
+                 this->osContext->getEngineType(),
+                 EngineHelpers::engineTypeToString(this->osContext->getEngineType()).c_str(),
+                 EngineHelpers::engineUsageToString(this->osContext->getEngineUsage()).c_str());
 }
 
 void CommandStreamReceiver::checkForNewResources(TaskCountType submittedTaskCount, TaskCountType allocationTaskCount, GraphicsAllocation &gfxAllocation) {
     if (useNewResourceImplicitFlush) {
         if (allocationTaskCount == GraphicsAllocation::objectNotUsed && !GraphicsAllocation::isIsaAllocationType(gfxAllocation.getAllocationType())) {
             newResources = true;
-            if (debugManager.flags.ProvideVerboseImplicitFlush.get()) {
-                printf("New resource detected of type %llu\n", static_cast<unsigned long long>(gfxAllocation.getAllocationType()));
-            }
+            PRINT_STRING(debugManager.flags.ProvideVerboseImplicitFlush.get(), stdout,
+                         "New resource detected of type %llu\n", static_cast<unsigned long long>(gfxAllocation.getAllocationType()));
         }
     }
 }
@@ -1196,27 +1202,27 @@ bool CommandStreamReceiver::createPerDssBackedBuffer(Device &device) {
 void CommandStreamReceiver::printTagAddressContent(TaskCountType taskCountToWait, int64_t waitTimeout, bool start) {
     if (getType() == NEO::CommandStreamReceiverType::aub) {
         if (start) {
-            PRINT_DEBUG_STRING(true, stdout, "\nAub dump wait for task count %llu", taskCountToWait);
+            PRINT_STRING(true, stdout, "\nAub dump wait for task count %llu", taskCountToWait);
         } else {
-            PRINT_DEBUG_STRING(true, stdout, "\nAub dump wait completed.");
+            PRINT_STRING(true, stdout, "\nAub dump wait completed.");
         }
         return;
     }
     auto postSyncAddress = getTagAddress();
     if (start) {
-        PRINT_DEBUG_STRING(true, stdout,
-                           "\nWaiting for task count %llu at location %p with timeout %llx. Current value:",
-                           taskCountToWait, postSyncAddress, waitTimeout);
+        PRINT_STRING(true, stdout,
+                     "\nWaiting for task count %llu at location %p with timeout %llx. Current value:",
+                     taskCountToWait, postSyncAddress, waitTimeout);
     } else {
-        PRINT_DEBUG_STRING(true, stdout,
-                           "%s", "\nWaiting completed. Current value:");
+        PRINT_STRING(true, stdout,
+                     "%s", "\nWaiting completed. Current value:");
     }
 
     for (uint32_t i = 0; i < activePartitions; i++) {
-        PRINT_DEBUG_STRING(true, stdout, " %u", *postSyncAddress);
+        PRINT_STRING(true, stdout, " %u", *postSyncAddress);
         postSyncAddress = ptrOffset(postSyncAddress, this->immWritePostSyncWriteOffset);
     }
-    PRINT_DEBUG_STRING(true, stdout, "%s", "\n");
+    PRINT_STRING(true, stdout, "%s", "\n");
 }
 
 bool CommandStreamReceiver::isTbxMode() const {
