@@ -7,8 +7,8 @@
 
 #pragma once
 
+#include <cstddef>
 #include <cstdint>
-#include <stddef.h>
 
 namespace NEO {
 
