@@ -207,7 +207,7 @@ bool Device::initializeCommonResources() {
         auto rootDeviceEnvironment = getExecutionEnvironment()->rootDeviceEnvironments[rootDeviceIndex].get();
         rootDeviceEnvironment->initDebuggerL0(this);
         if (rootDeviceEnvironment->debugger == nullptr) {
-            NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Debug mode is not enabled in the system.\n");
+            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Debug mode is not enabled in the system.\n");
             return false;
         }
     }
@@ -221,7 +221,7 @@ bool Device::initializeCommonResources() {
             if (debugSurfaceSize) {
                 allocateDebugSurface(debugSurfaceSize);
             } else {
-                NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Unable to determine debug surface size.\n");
+                PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Unable to determine debug surface size.\n");
                 return false;
             }
         }
@@ -329,8 +329,6 @@ bool Device::initDeviceFully() {
         }
     }
 
-    executionEnvironment->memoryManager->setForce32BitAllocations(getDeviceInfo().force32BitAddresses);
-
     if (debugManager.flags.EnableSWTags.get() && !getRootDeviceEnvironment().tagsManager->isInitialized()) {
         getRootDeviceEnvironment().tagsManager->initialize(*this);
     }
@@ -1291,6 +1289,17 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
 
     std::lock_guard<std::mutex> guard(mutex);
 
+    auto findMatchingPriority = [&](const std::vector<int32_t> &indices, int requested, int fallback) -> uint32_t {
+        for (uint32_t i = 0; i < indices.size(); i++) {
+            uint32_t matching = indices[i];
+            if (engines[matching].osContext->hasPriorityLevel() &&
+                engines[matching].osContext->getPriorityLevel() == requested) {
+                return matching;
+            }
+        }
+        return fallback;
+    };
+
     if (usage == EngineUsage::highPriority) {
         if (highPriorityEnginesTotal == 0) {
             return nullptr;
@@ -1311,6 +1320,11 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
         else {
             auto index = (highPriorityCounter.fetch_add(1)) % (hpIndices.size());
             secondaryEngineIndex = hpIndices[index];
+            // Prefer matching priority when reusing an initialized HP context
+            if (priorityLevel.has_value()) {
+                const int requested = priorityLevel.value();
+                secondaryEngineIndex = findMatchingPriority(hpIndices, requested, secondaryEngineIndex);
+            }
         }
 
         if (engines[secondaryEngineIndex].osContext->getEngineUsage() != EngineUsage::highPriority) {
@@ -1321,7 +1335,9 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
         if (regularEnginesTotal == 0) {
             return nullptr;
         }
-        bool isSamePriorityLevel = priorityLevel.has_value() ? priorityLevel.value() == engines[secondaryEngineIndex].osContext->getPriorityLevel() : true;
+        bool isSamePriorityLevel = (priorityLevel.has_value() && engines[secondaryEngineIndex].osContext->hasPriorityLevel())
+                                       ? (priorityLevel.value() == engines[secondaryEngineIndex].osContext->getPriorityLevel())
+                                       : true;
         if (npIndices.size() == 0 && isSamePriorityLevel) {
             regularCounter.fetch_add(1);
             npIndices.push_back(secondaryEngineIndex);
@@ -1336,6 +1352,11 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
         else {
             auto index = (regularCounter.fetch_add(1)) % (npIndices.size());
             secondaryEngineIndex = npIndices[index];
+            // Prefer matching priority when reusing an initialized regular context
+            if (priorityLevel.has_value()) {
+                const int requested = priorityLevel.value();
+                secondaryEngineIndex = findMatchingPriority(npIndices, requested, secondaryEngineIndex);
+            }
         }
     } else {
         DEBUG_BREAK_IF(true);
@@ -1347,10 +1368,11 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
     if (debugManager.flags.PrintSecondaryContextEngineInfo.get()) {
         std::stringstream contextEngineInfo;
         contextEngineInfo << "SecondaryContexts::getEngine-> engineUsage: " << EngineHelpers::engineUsageToString(usage).c_str() << " index: " << secondaryEngineIndex << " priorityLevel: " << (engines[secondaryEngineIndex].osContext->hasPriorityLevel() ? std::to_string(engines[secondaryEngineIndex].osContext->getPriorityLevel()) : "std::nullopt") << " \n";
-        PRINT_DEBUG_STRING(debugManager.flags.PrintSecondaryContextEngineInfo.get(), stdout, "%s", contextEngineInfo.str().c_str());
+        PRINT_STRING(debugManager.flags.PrintSecondaryContextEngineInfo.get(), stdout, "%s", contextEngineInfo.str().c_str());
     }
     return &engines[secondaryEngineIndex];
 }
+
 void Device::stopDirectSubmissionForCopyEngine() {
     auto internalBcsEngine = getInternalCopyEngine();
     if (internalBcsEngine == nullptr || getHardwareInfo().featureTable.ftrBcsInfo.count() > 1) {
