@@ -198,11 +198,6 @@ size_t BlitCommandsHelper<GfxFamily>::getSizeForGlobalSequencerFlush() {
     return 0u;
 }
 
-template <typename GfxFamily>
-bool BlitCommandsHelper<GfxFamily>::miArbCheckWaRequired() {
-    return false;
-}
-
 template <typename GfxFamily>
 void BlitCommandsHelper<GfxFamily>::appendClearColor(const BlitProperties &blitProperties, typename GfxFamily::XY_BLOCK_COPY_BLT &blitCmd) {
 }
@@ -234,7 +229,7 @@ size_t CommandStreamReceiverHw<Family>::getCmdSizeForL3Config() const {
 
 template <>
 void populateFactoryTable<CommandStreamReceiverHw<Family>>() {
-    extern CommandStreamReceiverCreateFunc commandStreamReceiverFactory[2 * IGFX_MAX_CORE];
+    extern CommandStreamReceiverCreateFunc commandStreamReceiverFactory[2 * NEO::maxCoreEnumValue];
     commandStreamReceiverFactory[gfxCore] = DeviceCommandStreamReceiver<Family>::create;
 }
 
