@@ -29,7 +29,7 @@ bool TbxCommandStreamReceiverHw<Family>::getpollNotEqualValueForPollForCompletio
 
 template <>
 void populateFactoryTable<TbxCommandStreamReceiverHw<Family>>() {
-    extern TbxCommandStreamReceiverCreateFunc tbxCommandStreamReceiverFactory[IGFX_MAX_CORE];
+    extern TbxCommandStreamReceiverCreateFunc tbxCommandStreamReceiverFactory[NEO::maxCoreEnumValue];
     UNRECOVERABLE_IF(!isInRange(gfxCore, tbxCommandStreamReceiverFactory));
     tbxCommandStreamReceiverFactory[gfxCore] = TbxCommandStreamReceiverHw<Family>::create;
 }
