@@ -8,8 +8,8 @@
 #pragma once
 #include "shared/source/gmm_helper/gmm_resource_usage_type.h"
 
+#include <cstddef>
 #include <cstdint>
-#include <stddef.h>
 
 namespace CacheSettings {
 inline constexpr uint32_t unknownMocs = -1;
@@ -33,5 +33,6 @@ struct CacheSettingsHelper {
   protected:
     static GmmResourceUsageType getDefaultUsageTypeWithCachingEnabled(AllocationType allocationType, const ProductHelper &productHelper, const HardwareInfo *hwInfo);
     static GmmResourceUsageType getDefaultUsageTypeWithCachingDisabled(AllocationType allocationType, const ProductHelper &productHelper);
+    static bool isCpuCachingOfDeviceBuffersAllowed(const RootDeviceEnvironment &rootDeviceEnvironment);
 };
 } // namespace NEO
