@@ -8,6 +8,6 @@
 #include "shared/source/gmm_helper/gmm_callbacks.h"
 
 namespace NEO {
-NotifyAubCaptureFunc notifyAubCaptureFuncFactory[IGFX_MAX_CORE]{};
-WriteL3AddressFunc writeL3AddressFuncFactory[IGFX_MAX_CORE]{};
+NotifyAubCaptureFunc notifyAubCaptureFuncFactory[NEO::maxCoreEnumValue]{};
+WriteL3AddressFunc writeL3AddressFuncFactory[NEO::maxCoreEnumValue]{};
 } // namespace NEO
