@@ -8,8 +8,8 @@
 #pragma once
 #include "neo_igfxfmid.h"
 
+#include <cstddef>
 #include <cstdint>
-#include <stddef.h>
 
 #ifndef _WIN32
 #define __stdcall
@@ -19,8 +19,8 @@ namespace NEO {
 using NotifyAubCaptureFunc = long(__stdcall *)(void *csrHandle, uint64_t gfxAddress, size_t gfxSize, bool allocate);
 using WriteL3AddressFunc = int(__stdcall *)(void *queueHandle, uint64_t l3GfxAddress, uint64_t regOffset);
 
-extern NotifyAubCaptureFunc notifyAubCaptureFuncFactory[IGFX_MAX_CORE];
-extern WriteL3AddressFunc writeL3AddressFuncFactory[IGFX_MAX_CORE];
+extern NotifyAubCaptureFunc notifyAubCaptureFuncFactory[NEO::maxCoreEnumValue];
+extern WriteL3AddressFunc writeL3AddressFuncFactory[NEO::maxCoreEnumValue];
 
 template <typename GfxFamily>
 struct GmmCallbacks {
