@@ -20,10 +20,6 @@
 #include <cstdint>
 #include <memory>
 
-namespace AubMemDump {
-struct LrcaHelper;
-}
-
 namespace NEO {
 enum class AuxTranslationMode;
 struct FeatureTable;
@@ -218,6 +214,8 @@ class GfxCoreHelper {
 
     virtual bool isExtendedUsmPoolSizeEnabled() const = 0;
     virtual bool crossEngineCacheFlushRequired() const = 0;
+    int32_t getHighestQueuePriorityLevel() const;
+    int32_t getLowestQueuePriorityLevel() const;
 
     virtual ~GfxCoreHelper() = default;
 
