@@ -261,7 +261,8 @@ class GraphicsAllocation : public IDNode<GraphicsAllocation>, NEO::NonCopyableAn
     static bool is2MBPageAllocationType(AllocationType type) {
         return type == AllocationType::timestampPacketTagBuffer ||
                type == AllocationType::gpuTimestampDeviceBuffer ||
-               type == AllocationType::profilingTagBuffer;
+               type == AllocationType::profilingTagBuffer ||
+               type == AllocationType::printfSurface;
     }
 
     static bool isAccessedFromCommandStreamer(AllocationType allocationType) {
@@ -269,6 +270,9 @@ class GraphicsAllocation : public IDNode<GraphicsAllocation>, NEO::NonCopyableAn
                allocationType == AllocationType::ringBuffer ||
                allocationType == AllocationType::semaphoreBuffer;
     }
+    static bool isZeroInitRequired(AllocationType allocationType) {
+        return allocationType == AllocationType::preemption;
+    }
 
     static uint32_t getNumHandlesForKmdSharedAllocation(uint32_t numBanks);
 
