@@ -10,6 +10,7 @@
 #include "shared/source/helpers/common_types.h"
 #include "shared/source/helpers/constants.h"
 #include "shared/source/helpers/device_bitfield.h"
+#include "shared/source/helpers/memory_properties_flags.h"
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/memory_manager/memadvise_flags.h"
 #include "shared/source/memory_manager/multi_graphics_allocation.h"
@@ -18,8 +19,6 @@
 #include "shared/source/utilities/sorted_vector.h"
 #include "shared/source/utilities/spinlock.h"
 
-#include "memory_properties_flags.h"
-
 #include <atomic>
 #include <chrono>
 #include <cstdint>
@@ -158,8 +157,8 @@ class SVMAllocsManager {
         void *allocation;
         SvmAllocationData *svmData;
         std::chrono::high_resolution_clock::time_point saveTime;
-        bool completed;
-        SvmCacheAllocationInfo(size_t allocationSize, void *allocation, SvmAllocationData *svmData, bool completed) : allocationSize(allocationSize), allocation(allocation), svmData(svmData), completed(completed) {
+        bool isInUseCheckRequired;
+        SvmCacheAllocationInfo(size_t allocationSize, void *allocation, SvmAllocationData *svmData, bool isInUseCheckRequired) : allocationSize(allocationSize), allocation(allocation), svmData(svmData), isInUseCheckRequired(isInUseCheckRequired) {
             saveTime = std::chrono::high_resolution_clock::now();
         }
         bool operator<(SvmCacheAllocationInfo const &other) const {
@@ -183,6 +182,11 @@ class SVMAllocsManager {
             trim,
             trimOld
         };
+        enum class CompletionCheckPolicy {
+            waitOnFree,
+            deferred,
+            notRequired,
+        };
 
         struct SvmAllocationCachePerfInfo {
             uint64_t allocationSize;
@@ -199,7 +203,7 @@ class SVMAllocsManager {
         SvmAllocationCache();
 
         static bool sizeAllowed(size_t size) { return size <= SvmAllocationCache::maxServicedSize; }
-        bool insert(size_t size, void *ptr, SvmAllocationData *svmData, bool waitForCompletion);
+        bool insert(size_t size, void *ptr, SvmAllocationData *svmData, CompletionCheckPolicy completionCheckPolicy);
         static bool allocUtilizationAllows(size_t requestedSize, size_t reuseCandidateSize);
         static bool alignmentAllows(void *ptr, size_t alignment);
         bool isInUse(SvmCacheAllocationInfo &cacheAllocInfo);
@@ -259,8 +263,9 @@ class SVMAllocsManager {
 
     MOCKABLE_VIRTUAL bool freeSVMAlloc(void *ptr, bool blocking);
     MOCKABLE_VIRTUAL bool freeSVMAllocDefer(void *ptr);
-    MOCKABLE_VIRTUAL void freeSVMAllocDeferImpl();
     MOCKABLE_VIRTUAL void freeSVMAllocImpl(void *ptr, FreePolicyType policy, SvmAllocationData *svmData);
+    void freeSVMAllocDeferImpl() { this->freeSVMAllocDeferImpl(FreePolicyType::defer); }
+    void freeSVMAllocDeferImplBlocking() { this->freeSVMAllocDeferImpl(FreePolicyType::blocking); }
     bool freeSVMAlloc(void *ptr) { return freeSVMAlloc(ptr, false); }
     void cleanupUSMAllocCaches();
     void trimUSMDeviceAllocCache();
@@ -306,6 +311,7 @@ class SVMAllocsManager {
     void waitForEnginesCompletion(SvmAllocationData *allocationData);
 
   protected:
+    void freeSVMAllocDeferImpl(FreePolicyType policy);
     void *createZeroCopySvmAllocation(size_t size, const SvmAllocationProperties &svmProperties,
                                       const RootDeviceIndicesContainer &rootDeviceIndices,
                                       const std::map<uint32_t, DeviceBitfield> &subdeviceBitfields);
