@@ -117,7 +117,6 @@ class ProductHelperHw : public ProductHelper {
     bool isStatefulAddressingModeSupported() const override;
     uint32_t getNumberOfPartsInTileForConcurrentKernel(uint32_t ccsCount) const override;
     bool isPlatformQuerySupported() const override;
-    bool isNonBlockingGpuSubmissionSupported() const override;
     bool isResolveDependenciesByPipeControlsSupported(const HardwareInfo &hwInfo, bool isOOQ, TaskCountType queueTaskCount, const CommandStreamReceiver &queueCsr) const override;
     bool isBufferPoolAllocatorSupported() const override;
     bool isHostUsmPoolAllocatorSupported() const override;
@@ -166,7 +165,7 @@ class ProductHelperHw : public ProductHelper {
     void fillFrontEndPropertiesSupportStructure(FrontEndPropertiesSupport &propertiesSupport, const HardwareInfo &hwInfo) const override;
     void fillPipelineSelectPropertiesSupportStructure(PipelineSelectPropertiesSupport &propertiesSupport, const HardwareInfo &hwInfo) const override;
     void fillStateBaseAddressPropertiesSupportStructure(StateBaseAddressPropertiesSupport &propertiesSupport) const override;
-    void parseCcsMode(std::string ccsModeString, std::unordered_map<uint32_t, uint32_t> &rootDeviceNumCcsMap, uint32_t rootDeviceIndex, RootDeviceEnvironment *rootDeviceEnvironment) const override;
+    bool parseCcsMode(std::string ccsModeString, std::unordered_map<uint32_t, uint32_t> &rootDeviceNumCcsMap, uint32_t rootDeviceIndex, RootDeviceEnvironment *rootDeviceEnvironment) const override;
 
     bool isFusedEuDisabledForDpas(bool kernelHasDpasInstructions, const uint32_t *lws, const uint32_t *groupCount, const HardwareInfo &hwInfo) const override;
     bool isCalculationForDisablingEuFusionWithDpasNeeded(const HardwareInfo &hwInfo) const override;
@@ -179,13 +178,11 @@ class ProductHelperHw : public ProductHelper {
     aub_stream::EngineType getDefaultCopyEngine() const override;
     void adjustEngineGroupType(EngineGroupType &engineGroupType) const override;
     std::optional<GfxMemoryAllocationMethod> getPreferredAllocationMethod(AllocationType allocationType) const override;
-    bool isCachingOnCpuAvailable() const override;
     bool isNewCoherencyModelSupported() const override;
     bool isResourceUncachedForCS(AllocationType allocationType) const override;
     bool deferMOCSToPatIndex(bool isWddmOnLinux) const override;
     bool supportReadOnlyAllocations() const override;
     const std::vector<uint32_t> getSupportedLocalDispatchSizes(const HardwareInfo &hwInfo) const override;
-    uint32_t getMaxLocalRegionSize(const HardwareInfo &hwInfo) const override;
     uint32_t getMaxLocalSubRegionSize(const HardwareInfo &hwInfo) const override;
     bool localDispatchSizeQuerySupported() const override;
     bool isDeviceToHostCopySignalingFenceRequired() const override;
@@ -210,6 +207,7 @@ class ProductHelperHw : public ProductHelper {
     bool isCompressionForbidden(const HardwareInfo &hwInfo) const override;
     bool isExposingSubdevicesAllowed() const override;
     bool useAdditionalBlitProperties() const override;
+    bool isFlushBetweenBlitsRequired() const override;
     bool isNonCoherentTimestampsModeEnabled() const override;
     bool getStorageInfoLocalOnlyFlag(LocalMemAllocationMode usmDeviceAllocationMode, bool defaultValue) const override;
     bool isPidFdOrSocketForIpcSupported() const override;
@@ -221,6 +219,8 @@ class ProductHelperHw : public ProductHelper {
     bool isDeviceCapsReaderSupported() const override;
     bool isMediaContextSupported() const override;
     bool sipUsesSubslicePools() const override;
+    bool isScratchSpaceBasePointerInGrf() const override;
+    bool scanFullTopologyBitmap() const override;
 
     ~ProductHelperHw() override = default;
 
