@@ -54,7 +54,7 @@ Wddm::CreateDXGIFactoryFcn Wddm::createDxgiFactory = getCreateDxgiFactory();
 Wddm::GetSystemInfoFcn Wddm::getSystemInfo = getGetSystemInfo();
 
 Wddm::Wddm(std::unique_ptr<HwDeviceIdWddm> &&hwDeviceIdIn, RootDeviceEnvironment &rootDeviceEnvironment)
-    : DriverModel(DriverModelType::wddm), hwDeviceId(std::move(hwDeviceIdIn)), rootDeviceEnvironment(rootDeviceEnvironment) {
+    : DriverModel(DriverModelType::wddm), residencyController(*this), hwDeviceId(std::move(hwDeviceIdIn)), rootDeviceEnvironment(rootDeviceEnvironment) {
     UNRECOVERABLE_IF(!hwDeviceId);
     featureTable.reset(new FeatureTable());
     workaroundTable.reset(new WorkaroundTable());
@@ -304,6 +304,12 @@ bool Wddm::queryAdapterInfo() {
         if (debugManager.flags.ForceDeviceId.get() != "unk") {
             gfxPlatform->usDeviceID = static_cast<unsigned short>(std::stoi(debugManager.flags.ForceDeviceId.get(), nullptr, 16));
         }
+        if (debugManager.flags.ForceProductFamily.get() != "unk") {
+            gfxPlatform->eProductFamily = static_cast<PRODUCT_FAMILY>(std::stoi(debugManager.flags.ForceProductFamily.get(), nullptr, 0));
+        }
+        if (debugManager.flags.ForceCoreFamily.get() != "unk") {
+            gfxPlatform->eRenderCoreFamily = static_cast<GFXCORE_FAMILY>(std::stoi(debugManager.flags.ForceCoreFamily.get(), nullptr, 0));
+        }
 
         SkuInfoReceiver::receiveFtrTableFromAdapterInfo(featureTable.get(), &adapterInfo);
         SkuInfoReceiver::receiveWaTableFromAdapterInfo(workaroundTable.get(), &adapterInfo);
@@ -417,7 +423,7 @@ std::unique_ptr<HwDeviceIdWddm> createHwDeviceIdFromAdapterLuid(OsEnvironmentWin
     std::unique_ptr<UmKmDataTranslator> umKmDataTranslator = createUmKmDataTranslator(*osEnvironment.gdi, openAdapterData.hAdapter);
     if (false == umKmDataTranslator->enabled() && !debugManager.flags.DoNotValidateDriverPath.get()) {
         if (false == validDriverStorePath(osEnvironment, openAdapterData.hAdapter)) {
-            PRINT_DEBUG_STRING(debugManager.flags.PrintDebugMessages.get(), stderr, "Driver path is not a valid DriverStore path. Try running with debug key: DoNotValidateDriverPath=1.\n");
+            PRINT_STRING(debugManager.flags.PrintDebugMessages.get(), stderr, "Driver path is not a valid DriverStore path. Try running with debug key: DoNotValidateDriverPath=1.\n");
             return nullptr;
         }
     }
@@ -568,13 +574,18 @@ bool Wddm::mapGpuVirtualAddress(AllocationStorageData *allocationStorageData) {
     return mapGpuVirtualAddress(osHandle->gmm,
                                 osHandle->handle,
                                 0u, MemoryConstants::maxSvmAddress, castToUint64(allocationStorageData->cpuPtr),
-                                osHandle->gpuPtr, AllocationType::externalHostPtr);
+                                osHandle->gpuPtr, AllocationType::externalHostPtr, nullptr);
 }
 
-bool Wddm::mapGpuVirtualAddress(Gmm *gmm, D3DKMT_HANDLE handle, D3DGPU_VIRTUAL_ADDRESS minimumAddress, D3DGPU_VIRTUAL_ADDRESS maximumAddress, D3DGPU_VIRTUAL_ADDRESS preferredAddress, D3DGPU_VIRTUAL_ADDRESS &gpuPtr, AllocationType type) {
+bool Wddm::mapGpuVirtualAddress(Gmm *gmm, D3DKMT_HANDLE handle, D3DGPU_VIRTUAL_ADDRESS minimumAddress, D3DGPU_VIRTUAL_ADDRESS maximumAddress, D3DGPU_VIRTUAL_ADDRESS preferredAddress, D3DGPU_VIRTUAL_ADDRESS &gpuPtr, AllocationType type, const MemoryFlags *flags) {
     D3DDDI_MAPGPUVIRTUALADDRESS mapGPUVA = {};
     D3DDDIGPUVIRTUALADDRESS_PROTECTION_TYPE protectionType = {};
-    protectionType.Write = TRUE;
+    if (flags) {
+        protectionType.Write = flags->readWrite;
+        protectionType.NoAccess = flags->noAccess;
+    } else {
+        protectionType.Write = TRUE;
+    }
 
     uint64_t size = gmm->gmmResourceInfo->getSizeAllocation();
 
@@ -610,7 +621,7 @@ bool Wddm::mapGpuVirtualAddress(Gmm *gmm, D3DKMT_HANDLE handle, D3DGPU_VIRTUAL_A
     bool ret = true;
     auto &productHelper = rootDeviceEnvironment.getHelper<ProductHelper>();
     if (gmm->isCompressionEnabled() && productHelper.isPageTableManagerSupported(*rootDeviceEnvironment.getHardwareInfo())) {
-        this->forEachContextWithinWddm([&](const EngineControl &engine) {
+        this->forEachContextWithinWddm<false>([&](const EngineControl &engine) {
             if (engine.commandStreamReceiver->pageTableManager.get()) {
                 ret &= engine.commandStreamReceiver->pageTableManager->updateAuxTable(gpuPtr, gmm, true);
             }
@@ -803,7 +814,7 @@ NTSTATUS Wddm::createAllocationsAndMapGpuVa(OsHandleStorage &osHandles) {
         }
 
         if (status != STATUS_SUCCESS) {
-            PRINT_DEBUG_STRING(debugManager.flags.PrintDebugMessages.get(), stderr, "%s status: %d", __FUNCTION__, status);
+            PRINT_STRING(debugManager.flags.PrintDebugMessages.get(), stderr, "%s status: %d", __FUNCTION__, status);
             DEBUG_BREAK_IF(status != STATUS_GRAPHICS_NO_VIDEO_MEMORY);
             break;
         }
@@ -817,7 +828,7 @@ NTSTATUS Wddm::createAllocationsAndMapGpuVa(OsHandleStorage &osHandles) {
 
             if (!success) {
                 osHandles.fragmentStorageData[allocationIndex].freeTheFragment = true;
-                PRINT_DEBUG_STRING(debugManager.flags.PrintDebugMessages.get(), stderr, "%s mapGpuVirtualAddress: %d", __FUNCTION__, success);
+                PRINT_STRING(debugManager.flags.PrintDebugMessages.get(), stderr, "%s mapGpuVirtualAddress: %d", __FUNCTION__, success);
                 DEBUG_BREAK_IF(true);
                 return STATUS_GRAPHICS_NO_VIDEO_MEMORY;
             }
@@ -906,7 +917,9 @@ bool Wddm::openSharedHandle(const MemoryManager::OsHandleData &osHandleData, Wdd
     alloc->setResourceHandle(openResource.hResource);
 
     auto resourceInfo = const_cast<void *>(allocationInfo[allocationInfoIndex].pPrivateDriverData);
-    alloc->setDefaultGmm(new Gmm(rootDeviceEnvironment.getGmmHelper(), static_cast<GMM_RESOURCE_INFO *>(resourceInfo)));
+    auto gmmHelper = rootDeviceEnvironment.getGmmHelper();
+    auto gmmResourceInfo = std::unique_ptr<GmmResourceInfo>(GmmResourceInfo::create(gmmHelper->getClientContext(), static_cast<GMM_RESOURCE_INFO *>(resourceInfo)));
+    alloc->setDefaultGmm(new Gmm(gmmHelper, gmmResourceInfo.get()));
 
     return true;
 }
@@ -955,7 +968,9 @@ bool Wddm::openNTHandle(const MemoryManager::OsHandleData &osHandleData, WddmAll
     auto allocationInfoIndex = osHandleData.arrayIndex < queryResourceInfoFromNtHandle.NumAllocations ? osHandleData.arrayIndex : 0;
     auto resourceInfo = const_cast<void *>(allocationInfo2[allocationInfoIndex].pPrivateDriverData);
 
-    alloc->setDefaultGmm(new Gmm(rootDeviceEnvironment.getGmmHelper(), static_cast<GMM_RESOURCE_INFO *>(resourceInfo), hwDeviceId->getUmKmDataTranslator()->enabled()));
+    auto gmmHelper = rootDeviceEnvironment.getGmmHelper();
+    auto gmmResourceInfo = std::unique_ptr<GmmResourceInfo>(GmmResourceInfo::create(gmmHelper->getClientContext(), static_cast<GMM_RESOURCE_INFO *>(resourceInfo)));
+    alloc->setDefaultGmm(new Gmm(gmmHelper, gmmResourceInfo.get(), hwDeviceId->getUmKmDataTranslator()->enabled()));
 
     alloc->setDefaultHandle(allocationInfo2[allocationInfoIndex].hAllocation);
     alloc->setResourceHandle(openResourceFromNtHandle.hResource);
@@ -1007,9 +1022,9 @@ bool Wddm::setLowPriorityContextParam(D3DKMT_HANDLE contextHandle) {
 
     auto status = getGdi()->setSchedulingPriority(&contextPriority);
 
-    PRINT_DEBUG_STRING(debugManager.flags.PrintDebugMessages.get(), stdout,
-                       "\nSet scheduling priority for Wddm context. Status: :%lu, context handle: %u, priority: %d \n",
-                       status, contextHandle, contextPriority.Priority);
+    PRINT_STRING(debugManager.flags.PrintDebugMessages.get(), stdout,
+                 "\nSet scheduling priority for Wddm context. Status: :%lu, context handle: %u, priority: %d \n",
+                 status, contextHandle, contextPriority.Priority);
 
     return (status == STATUS_SUCCESS);
 }
@@ -1061,9 +1076,9 @@ bool Wddm::createContext(OsContextWin &osContext) {
     status = getGdi()->createContext(&createContext);
     osContext.setWddmContextHandle(createContext.hContext);
 
-    PRINT_DEBUG_STRING(debugManager.flags.PrintDebugMessages.get(), stdout,
-                       "\nCreated Wddm context. Status: :%lu, engine: %u, contextId: %u, deviceBitfield: %lu \n",
-                       status, osContext.getEngineType(), osContext.getContextId(), osContext.getDeviceBitfield().to_ulong());
+    PRINT_STRING(debugManager.flags.PrintDebugMessages.get(), stdout,
+                 "\nCreated Wddm context. Status: :%lu, engine: %u, contextId: %u, deviceBitfield: %lu \n",
+                 status, osContext.getEngineType(), osContext.getContextId(), osContext.getDeviceBitfield().to_ulong());
 
     if (status != STATUS_SUCCESS) {
         return false;
@@ -1093,9 +1108,8 @@ bool Wddm::submit(uint64_t commandBuffer, size_t size, void *commandHeader, Wddm
     }
     DBG_LOG(ResidencyDebugEnable, "Residency:", __FUNCTION__, "currentFenceValue =", submitArguments.monitorFence->currentFenceValue);
 
-    if (debugManager.flags.PrintDeviceAndEngineIdOnSubmission.get()) {
-        printf("%u: Wddm Submission with context handle %u and HwQueue handle %u\n", SysCalls::getProcessId(), submitArguments.contextHandle, submitArguments.hwQueueHandle);
-    }
+    PRINT_STRING(debugManager.flags.PrintDeviceAndEngineIdOnSubmission.get(), stdout,
+                 "%u: Wddm Submission with context handle %u and HwQueue handle %u\n", SysCalls::getProcessId(), submitArguments.contextHandle, submitArguments.hwQueueHandle);
 
     status = getDeviceState();
     if (!status) {
@@ -1146,21 +1160,21 @@ bool Wddm::getDeviceState() {
         auto status = getDeviceExecutionState(D3DKMT_DEVICESTATE_EXECUTION, &executionState);
         if (status) {
             if (executionState == D3DKMT_DEVICEEXECUTION_ERROR_OUTOFMEMORY) {
-                PRINT_DEBUG_STRING(true, stderr, "Device execution error, out of memory %d\n", executionState);
+                PRINT_STRING(true, stderr, "Device execution error, out of memory %d\n", executionState);
             } else if (executionState == D3DKMT_DEVICEEXECUTION_ERROR_DMAPAGEFAULT) {
-                PRINT_DEBUG_STRING(true, stderr, "Device execution error, page fault\n", executionState);
+                PRINT_STRING(true, stderr, "Device execution error, page fault\n", executionState);
                 D3DKMT_DEVICEPAGEFAULT_STATE pageFaultState = {};
                 status = getDeviceExecutionState(D3DKMT_DEVICESTATE_PAGE_FAULT, &pageFaultState);
                 if (status) {
-                    PRINT_DEBUG_STRING(true, stderr, "faulted gpuva 0x%" PRIx64 ", ", pageFaultState.FaultedVirtualAddress);
-                    PRINT_DEBUG_STRING(true, stderr, "pipeline stage %d, bind table entry %u, flags 0x%x, error code(is device) %u, error code %u\n",
-                                       pageFaultState.FaultedPipelineStage, pageFaultState.FaultedBindTableEntry, pageFaultState.PageFaultFlags,
-                                       pageFaultState.FaultErrorCode.IsDeviceSpecificCode, pageFaultState.FaultErrorCode.IsDeviceSpecificCode ? pageFaultState.FaultErrorCode.DeviceSpecificCode : static_cast<UINT>(pageFaultState.FaultErrorCode.GeneralErrorCode));
+                    PRINT_STRING(true, stderr, "faulted gpuva 0x%" PRIx64 ", ", pageFaultState.FaultedVirtualAddress);
+                    PRINT_STRING(true, stderr, "pipeline stage %d, bind table entry %u, flags 0x%x, error code(is device) %u, error code %u\n",
+                                 pageFaultState.FaultedPipelineStage, pageFaultState.FaultedBindTableEntry, pageFaultState.PageFaultFlags,
+                                 pageFaultState.FaultErrorCode.IsDeviceSpecificCode, pageFaultState.FaultErrorCode.IsDeviceSpecificCode ? pageFaultState.FaultErrorCode.DeviceSpecificCode : static_cast<UINT>(pageFaultState.FaultErrorCode.GeneralErrorCode));
 
                     DBG_LOG(ResidencyDebugEnable, "Residency:", __FUNCTION__, "Page fault detected at address = ", std::hex, pageFaultState.FaultedVirtualAddress);
                 }
             } else if (executionState != D3DKMT_DEVICEEXECUTION_ACTIVE) {
-                PRINT_DEBUG_STRING(true, stderr, "Device execution error %d\n", executionState);
+                PRINT_STRING(true, stderr, "Device execution error %d\n", executionState);
             }
             DEBUG_BREAK_IF(executionState != D3DKMT_DEVICEEXECUTION_ACTIVE);
             return executionState == D3DKMT_DEVICEEXECUTION_ACTIVE;
@@ -1196,7 +1210,7 @@ bool Wddm::waitFromCpu(uint64_t lastFenceValue, const MonitoredFence &monitoredF
 
     if (!skipResourceCleanup() && lastFenceValue > *monitoredFence.cpuAddress) {
         CommandStreamReceiver *csr = nullptr;
-        this->forEachContextWithinWddm([&monitoredFence, &csr](const EngineControl &engine) {
+        this->forEachContextWithinWddm<false>([&monitoredFence, &csr](const EngineControl &engine) {
             auto &contextMonitoredFence = static_cast<OsContextWin *>(engine.osContext)->getMonitoredFence();
             if (contextMonitoredFence.cpuAddress == monitoredFence.cpuAddress) {
                 csr = engine.commandStreamReceiver;
@@ -1242,7 +1256,7 @@ bool Wddm::isGpuHangDetected(OsContext &osContext) {
     const auto &monitoredFence = osContextWin->getMonitoredFence();
     bool hangDetected = monitoredFence.cpuAddress && *monitoredFence.cpuAddress == gpuHangIndication;
 
-    PRINT_DEBUG_STRING(hangDetected && debugManager.flags.PrintDebugMessages.get(), stderr, "%s", "ERROR: GPU HANG detected!\n");
+    PRINT_STRING(hangDetected && debugManager.flags.PrintDebugMessages.get(), stderr, "%s", "ERROR: GPU HANG detected!\n");
 
     return hangDetected;
 }
@@ -1416,10 +1430,10 @@ void Wddm::createPagingFenceLogger() {
 }
 
 PhysicalDevicePciBusInfo Wddm::getPciBusInfo() const {
-    if (adapterBDF.Data == std::numeric_limits<uint32_t>::max()) {
+    if (adapterBDF.data == std::numeric_limits<uint32_t>::max()) {
         return PhysicalDevicePciBusInfo(PhysicalDevicePciBusInfo::invalidValue, PhysicalDevicePciBusInfo::invalidValue, PhysicalDevicePciBusInfo::invalidValue, PhysicalDevicePciBusInfo::invalidValue);
     }
-    return PhysicalDevicePciBusInfo(0, adapterBDF.Bus, adapterBDF.Device, adapterBDF.Function);
+    return PhysicalDevicePciBusInfo(0, adapterBDF.bus, adapterBDF.device, adapterBDF.function);
 }
 
 PhysicalDevicePciSpeedInfo Wddm::getPciSpeedInfo() const {
@@ -1439,7 +1453,7 @@ void Wddm::setNewResourceBoundToPageTable() {
     if (!this->rootDeviceEnvironment.getProductHelper().isTlbFlushRequired()) {
         return;
     }
-    this->forEachContextWithinWddm([](const EngineControl &engine) { engine.osContext->setNewResourceBound(); });
+    this->forEachContextWithinWddm<false>([](const EngineControl &engine) { engine.osContext->setNewResourceBound(); });
 }
 
 bool Wddm::needsNotifyAubCaptureCallback() const {
