@@ -52,6 +52,7 @@ std::unique_lock<SpinLock> WddmResidencyController::acquireTrimCallbackLock() {
  * @param[in] allocationsForResidency container of allocations which need to be resident.
  * @param[out] requiresBlockingResidencyHandling flag indicating whether wait for paging fence must be handled in user thread.
  * Setting to false means that it can be handled in background thread, which will signal semaphore after paging fence reaches required value.
+ * @param[in] csr command stream receiver to provide OS context.
  *
  * @note This method filters allocations which are already resident. After calling this method, passed allocationsForResidency will contain
  * only allocations which were not resident before.
@@ -59,6 +60,7 @@ std::unique_lock<SpinLock> WddmResidencyController::acquireTrimCallbackLock() {
  * @return returns true if all allocations either succeeded or are pending to be resident
  */
 bool WddmResidencyController::makeResidentResidencyAllocations(ResidencyContainer &allocationsForResidency, bool &requiresBlockingResidencyHandling, CommandStreamReceiver *csr) {
+    UNRECOVERABLE_IF(csr == nullptr);
     auto &osContext = static_cast<OsContextWin &>(csr->getOsContext());
     auto osContextId = osContext.getContextId();
     const size_t residencyCount = allocationsForResidency.size();
@@ -77,7 +79,7 @@ bool WddmResidencyController::makeResidentResidencyAllocations(ResidencyContaine
         while ((result = wddm.makeResident(handlesForResidency.data(), static_cast<uint32_t>(handlesForResidency.size()), false, &bytesToTrim, totalSize)) == false) {
             this->setMemoryBudgetExhausted();
             bool trimmingDone = this->trimResidencyToBudget(bytesToTrim);
-            if (!trimmingDone && csr) {
+            if (!trimmingDone) {
                 csr->stopDirectSubmission(false, false);
                 trimmingDone = this->trimResidencyToBudget(bytesToTrim);
             }
@@ -144,9 +146,11 @@ size_t WddmResidencyController::fillHandlesContainer(ResidencyContainer &allocat
         bool isAlreadyResident = true;
         if (fragmentCount > 0) {
             for (uint32_t allocationId = 0; allocationId < fragmentCount; allocationId++) {
-                handlesForResidency.push_back(static_cast<OsHandleWin *>(allocation->fragmentsStorage.fragmentStorageData[allocationId].osHandleStorage)->handle);
-                requiresBlockingResidencyHandling |= (allocation->getAllocationType() != AllocationType::buffer && allocation->getAllocationType() != AllocationType::bufferHostMemory);
-                isAlreadyResident = false;
+                if (!allocation->fragmentsStorage.fragmentStorageData[allocationId].residency->resident[osContextId]) {
+                    handlesForResidency.push_back(static_cast<OsHandleWin *>(allocation->fragmentsStorage.fragmentStorageData[allocationId].osHandleStorage)->handle);
+                    requiresBlockingResidencyHandling |= (allocation->getAllocationType() != AllocationType::buffer && allocation->getAllocationType() != AllocationType::bufferHostMemory);
+                    isAlreadyResident = false;
+                }
             }
         } else if (!residencyData.resident[osContextId]) {
             for (uint32_t gmmId = 0; gmmId < allocation->getNumGmms(); ++gmmId) {
@@ -180,6 +184,10 @@ void WddmResidencyController::removeAllocation(ResidencyContainer &container, Gr
     std::unique_lock<std::mutex> lock2(this->trimCallbackLock, std::defer_lock);
     std::lock(lock1, lock2);
 
+    this->removeAllocationImpl(container, gfxAllocation);
+}
+
+void WddmResidencyController::removeAllocationImpl(ResidencyContainer &container, GraphicsAllocation *gfxAllocation) {
     auto iter = std::find(container.begin(), container.end(), gfxAllocation);
     if (iter != container.end()) {
         container.erase(iter);
