@@ -9,6 +9,7 @@
 #include "shared/source/command_stream/aub_command_stream_receiver_hw_xehp_and_later.inl"
 #include "shared/source/helpers/array_count.h"
 #include "shared/source/helpers/populate_factory.h"
+#include "shared/source/xe3_core/hw_cmds_base.h"
 
 namespace NEO {
 
@@ -17,7 +18,7 @@ static auto gfxCore = IGFX_XE3_CORE;
 
 template <>
 void populateFactoryTable<AUBCommandStreamReceiverHw<Family>>() {
-    extern AubCommandStreamReceiverCreateFunc aubCommandStreamReceiverFactory[IGFX_MAX_CORE];
+    extern AubCommandStreamReceiverCreateFunc aubCommandStreamReceiverFactory[NEO::maxCoreEnumValue];
     UNRECOVERABLE_IF(!isInRange(gfxCore, aubCommandStreamReceiverFactory));
     aubCommandStreamReceiverFactory[gfxCore] = AUBCommandStreamReceiverHw<Family>::create;
 }
